/**
 * 根据省、市、区（县）匹配邮政编码
 * 概述：首先根据区（县）匹配，如果找到邮政编码，再根据匹配出的邮政编码与市级邮政编码做核对，如果前两位一致,则核对通过.不一致以市级邮政编码为准.再将邮政编码与省级核对,一致则通过,不一致以省级为准.
 * @Param province, city, district
 */
define([], function () {
	/**
	 * 根据省、市、区（县）匹配邮政编码
	 * 概述：首先根据区（县）匹配，如果找到邮政编码，再根据匹配出的邮政编码与市级邮政编码做核对，如果前两位一致,则核对通过.不一致以市级邮政编码为准.再将邮政编码与省级核对,一致则通过,不一致以省级为准.
	 * @Param province, city, district
	 */
	function findPostCode(province, city, district) {
	
	    if(province == "北京市" && city == "朝阳区"){
	        return "100020";
	    }
	    var _postcode = null;
	
	    var _districtCode = null;
	
	    var _cityCode = null;
	
	    var _provinceCode = null;
	    // 区（县）
	    if (district) {
	        _districtCode = searchPostCodeByKey(district);
	    }
	    // 市
	    if (city) {
	        _cityCode = searchPostCodeByKey(city)
	    }
	    // 省
	    if (province) {
	        _provinceCode = searchPostCodeByKey(province)
	    }
	
	    // 如果有区（县）邮政编码
	    if (_districtCode) {
	        // 与市级做核对
	        if (_cityCode) {
	            if (checkPostCodePrefix(_districtCode, _cityCode)) {
	                //核对通过, 继续与省级核对
	                if (_provinceCode) {
	                    // 通过, 则使用区(县)邮政编码
	                    if (checkPostCodePrefix(_provinceCode, _cityCode)) {
	                        _postcode = _districtCode;
	                    } else {
	                        // 不通过,使用省级邮政编码
	                        _postcode = _provinceCode;
	                    }
	                }
	            } else {
	                //区(县)与市级核对不通过, 使用市级邮政编码与省级邮政编码核对
	                if (_provinceCode) {
	                    if (checkPostCodePrefix(_provinceCode, _cityCode)) {
	                        _postcode = _cityCode;
	                    } else {
	                        _postcode = _provinceCode;
	                    }
	                } else {
	                    _postcode = _cityCode;
	                }
	            }
	        } else if (_provinceCode) {
	            if (checkPostCodePrefix(_provinceCode, _districtCode)) {
	                _postcode = _districtCode;
	            }
	        }
	    } else if (_cityCode) {
	        if (_provinceCode) {
	            _postcode = _cityCode;
	            if (checkPostCodePrefix(_provinceCode, _cityCode)) {
	                _postcode = _cityCode;
	            } else {
	                _postcode = _provinceCode;
	            }
	        }
	    } else {
	        _postcode = _provinceCode;
	    }
	
	    return _postcode;
	}
	
	function searchPostCodeByKey(key) {
	
	    var _postcode = null;
	
	    if (key) {
	        _postcode = postCode[key];
	    }
	
	    if (!_postcode && key.length > 1) {
	        _postcode = postCode[key.substring(0, key.length - 1)];
	    }
	
	    return _postcode;
	}
	
	function checkPostCodePrefix(code1, code2) {
	
	    if (code1.substring(0, 1) == code2.substring(0, 1)) {
	        return true;
	    }
	
	    var num = Number(code1) - Number(code2);
	
	    if (1 == Math.abs(num)) {
	        return true;
	    }
	
	    return false;
	}
	
	var postCode = {
	    "安徽省": "230000",
	    "合肥市": "230000",
	    "长丰县": "231100",
	    "芜湖市": "241000",
	    "镜湖区": "241000",
	    "新芜区": "241000",
	    "芜湖县": "241100",
	    "蚌埠市": "233000",
	    "龙子湖区": "233000",
	    "禹会区": "233000",
	    "怀远县": "233400",
	    "淮南市": "232000",
	    "大通区": "232000",
	    "谢家集区": "232000",
	    "潘集区": "232000",
	    "马鞍山市": "243000",
	    "金家庄区": "243000",
	    "雨山区": "243000",
	    "淮北市": "235000",
	    "杜集区": "235000",
	    "烈山区": "235000",
	    "铜陵市": "244000",
	    "铜官山区": "244000",
	    "郊区": "244000",
	    "安庆市": "246000",
	    "迎江区": "246000",
	    "郊区": "246000",
	    "枞阳县": "246700",
	    "太湖县": "246400",
	    "望江县": "246200",
	    "黄山市": "245000",
	    "屯溪区": "245000",
	    "徽州区": "245000",
	    "休宁县": "245400",
	    "滁州市": "239000",
	    "琅琊区": "239000",
	    "来安县": "239200",
	    "定远县": "233200",
	    "天长市": "239300",
	    "阜阳市": "236000",
	    "颍州区": "236000",
	    "颍泉区": "236000",
	    "太和县": "236600",
	    "颍上县": "236200",
	    "宿州市": "234000",
	    "墉桥区": "234000",
	    "萧县": "235200",
	    "巢湖市": "238000",
	    "居巢区": "238000",
	    "无为县": "238300",
	    "六安市": "237000",
	    "金安区": "237000",
	    "寿县": "232200",
	    "舒城县": "231300",
	    "亳州市": "236000",
	    "谯城区": "236800",
	    "蒙城县": "233500",
	    "池州市": "247100",
	    "贵池区": "247100",
	    "石台县": "245100",
	    "宣城市": "242000",
	    "宣州区": "242000",
	    "广德县": "242200",
	    "绩溪县": "245300",
	    "肥东县": "230000",
	    "肥西县": "231200",
	    "南陵县": "242400",
	    "马塘区": "241000",
	    "鸠江区": "241000",
	    "繁昌县": "241200",
	    "固镇县": "233700",
	    "蚌山区": "233000",
	    "淮上区": "233000",
	    "五河县": "233300",
	    "凤台县": "232100",
	    "田家庵区": "232000",
	    "八公山区": "232000",
	    "当涂县": "243100",
	    "花山区": "243000",
	    "濉溪县": "235100",
	    "相山区": "235000",
	    "铜陵县": "244100",
	    "狮子山区": "244000",
	    "桐城市": "231400",
	    "大观区": "246000",
	    "怀宁县": "246100",
	    "潜山县": "246300",
	    "宿松县": "246500",
	    "岳西县": "246600",
	    "祁门县": "245600",
	    "黄山区": "245000",
	    "歙县": "245200",
	    "黟县": "245500",
	    "明光市": "239400",
	    "南谯区": "239000",
	    "全椒县": "239500",
	    "凤阳县": "233100",
	    "界首市": "236500",
	    "颍东区": "236000",
	    "临泉县": "236400",
	    "阜南县": "236300",
	    "泗县": "234300",
	    "砀山县": "235300",
	    "灵璧县": "234200",
	    "和县": "238200",
	    "庐江县": "231500",
	    "含山县": "238100",
	    "裕安区": "237000",
	    "霍邱县": "237400",
	    "金寨县": "237300",
	    "利辛县": "236700",
	    "涡阳县": "233600",
	    "青阳县": "242800",
	    "东至县": "247200",
	    "宁国市": "242300",
	    "郎溪县": "242100",
	    "泾县": "242500",
	    "旌德县": "242600",
	    "北京市": "100000",
	    "东城区": "100010",
	    "崇文区": "100061",
	    "朝阳区": "100020",
	    "石景山区": "100043",
	    "门头沟区": "102300",
	    "通州区": "101100",
	    "昌平区": "102200",
	    "怀柔区": "101400",
	    "密云县": "101500",
	    "西城区": "100032",
	    "宣武区": "100054",
	    "丰台区": "100071",
	    "海淀区": "100080",
	    "房山区": "102400",
	    "顺义区": "101300",
	    "大兴区": "102600",
	    "平谷区": "101200",
	    "延庆县": "102100",
	    "重庆市": "400000",
	    "万州区": "404100",
	    "渝中区": "400000",
	    "江北区": "400000",
	    "九龙坡区": "400000",
	    "北碚区": "400700",
	    "双桥区": "400900",
	    "巴南区": "401320",
	    "长寿区": "401220",
	    "潼南县": "402660",
	    "大足县": "402360",
	    "璧山县": "402760",
	    "城口县": "405900",
	    "垫江县": "408300",
	    "忠县": "404300",
	    "云阳县": "404500",
	    "巫山县": "404700",
	    "石柱土家族自治县": "409100",
	    "酉阳土家族苗族自治县": "409800",
	    "江津市": "402260",
	    "永川市": "402160",
	    "涪陵区": "408000",
	    "大渡口区": "400000",
	    "沙坪坝区": "400000",
	    "南岸区": "400000",
	    "万盛区": "400800",
	    "渝北区": "401120",
	    "黔江区": "409000",
	    "綦江县": "401420",
	    "铜梁县": "402560",
	    "荣昌县": "402460",
	    "梁平县": "405200",
	    "丰都县": "408200",
	    "武隆县": "408500",
	    "开县": "405400",
	    "奉节县": "404600",
	    "巫溪县": "405800",
	    "秀山土家族苗族自治县": "409900",
	    "彭水苗族土家族自治县": "409600",
	    "合川市": "401520",
	    "南川市": "408400",
	    "广东省": "510000",
	    "广州市": "510000",
	    "东山区": "522000",
	    "越秀区": "510000",
	    "天河区": "510600",
	    "白云区": "510400",
	    "番禺区": "511400",
	    "增城市": "511300",
	    "韶关市": "512000",
	    "武江区": "512000",
	    "曲江区": "512100",
	    "仁化县": "512300",
	    "乳源瑶族自治县": "512600",
	    "乐昌市": "512200",
	    "深圳市": "518000",
	    "罗湖区": "518000",
	    "南山区": "518000",
	    "龙岗区": "518100",
	    "珠海市": "519000",
	    "香洲区": "519000",
	    "汕头市": "515000",
	    "龙湖区": "515000",
	    "濠江区": "515000",
	    "潮南区": "515100",
	    "佛山市": "528000",
	    "禅城区": "528000",
	    "顺德区": "528000",
	    "江门市": "529000",
	    "蓬江区": "529000",
	    "新会区": "529100",
	    "开平市": "529300",
	    "湛江市": "524000",
	    "赤坎区": "524000",
	    "坡头区": "524000",
	    "遂溪县": "524300",
	    "廉江市": "524400",
	    "茂名市": "525000",
	    "茂南区": "525000",
	    "电白县": "525400",
	    "化州市": "525100",
	    "肇庆市": "526000",
	    "端州区": "526000",
	    "广宁县": "526300",
	    "封开县": "526500",
	    "高要市": "526100",
	    "惠州市": "516000",
	    "惠城区": "516000",
	    "博罗县": "516100",
	    "梅州市": "514000",
	    "梅江区": "514000",
	    "大埔县": "514200",
	    "五华县": "514400",
	    "蕉岭县": "514100",
	    "汕尾市": "516600",
	    "城区": "516600",
	    "陆河县": "516700",
	    "河源市": "517000",
	    "源城区": "517000",
	    "龙川县": "517300",
	    "和平县": "517200",
	    "阳江市": "529500",
	    "江城区": "529500",
	    "阳东县": "529900",
	    "清远市": "511500",
	    "清城区": "511500",
	    "阳山县": "513100",
	    "连南瑶族自治县": "513300",
	    "英德市": "513000",
	    "东莞市": "523000",
	    "潮州市": "521000",
	    "湘桥区": "521000",
	    "揭阳市": "522000",
	    "榕城区": "522000",
	    "揭西县": "515400",
	    "云浮市": "527300",
	    "云城区": "527300",
	    "郁南县": "527100",
	    "从化市": "510900",
	    "荔湾区": "510000",
	    "海珠区": "510200",
	    "芳村区": "510000",
	    "黄埔区": "510700",
	    "花都区": "510800",
	    "南雄市": "512400",
	    "浈江区": "512000",
	    "始兴县": "512500",
	    "翁源县": "512600",
	    "新丰县": "511100",
	    "盐田区": "518000",
	    "福田区": "518000",
	    "宝安区": "518100",
	    "金湾区": "519090",
	    "斗门区": "519100",
	    "澄海区": "515800",
	    "金平区": "515000",
	    "潮阳区": "515100",
	    "南澳县": "515900",
	    "高明区": "528500",
	    "南海区": "528200",
	    "三水区": "528100",
	    "恩平市": "529400",
	    "江海区": "529000",
	    "台山市": "529200",
	    "鹤山市": "529700",
	    "吴川市": "524500",
	    "霞山区": "524000",
	    "麻章区": "524000",
	    "徐闻县": "524100",
	    "雷州市": "524200",
	    "信宜市": "525300",
	    "茂港区": "525000",
	    "高州市": "525200",
	    "四会市": "526200",
	    "鼎湖区": "526000",
	    "怀集县": "526400",
	    "德庆县": "526600",
	    "龙门县": "516800",
	    "惠阳区": "516200",
	    "惠东县": "516300",
	    "兴宁市": "514500",
	    "梅县": "514700",
	    "丰顺县": "514300",
	    "平远县": "514600",
	    "陆丰市": "516500",
	    "海丰县": "516400",
	    "东源县": "517500",
	    "紫金县": "517400",
	    "连平县": "517100",
	    "阳春市": "529600",
	    "阳西县": "529800",
	    "连州市": "513400",
	    "佛冈县": "511600",
	    "连山壮族瑶族自治县": "513200",
	    "清新县": "511800",
	    "中山市": "528400",
	    "饶平县": "515700",
	    "潮安县": "515600",
	    "普宁市": "515300",
	    "揭东县": "515500",
	    "惠来县": "515200",
	    "罗定市": "527200",
	    "新兴县": "527400",
	    "云安县": "527500",
	    "广西壮族自治区": "530000",
	    "南宁市": "530000",
	    "兴宁区": "530000",
	    "江南区": "530000",
	    "良庆区": "530200",
	    "武鸣县": "530100",
	    "马山县": "530600",
	    "宾阳县": "530400",
	    "柳州市": "545000",
	    "城中区": "545000",
	    "柳南区": "545000",
	    "柳江县": "545100",
	    "鹿寨县": "545600",
	    "融水苗族自治县": "545300",
	    "桂林市": "541000",
	    "秀峰区": "541000",
	    "象山区": "541000",
	    "雁山区": "541000",
	    "临桂县": "541100",
	    "全州县": "541500",
	    "永福县": "541800",
	    "龙胜各族自治县": "541700",
	    "平乐县": "542400",
	    "梧州市": "543000",
	    "万秀区": "543000",
	    "长洲区": "543000",
	    "藤县": "543300",
	    "北海市": "536000",
	    "海城区": "536000",
	    "铁山港区": "536000",
	    "防城港市": "538000",
	    "港口区": "538000",
	    "上思县": "535500",
	    "钦州市": "535000",
	    "钦南区": "535000",
	    "灵山县": "535400",
	    "贵港市": "537000",
	    "港北区": "537100",
	    "覃塘区": "537100",
	    "玉林市": "537000",
	    "玉州区": "537000",
	    "陆川县": "537700",
	    "兴业县": "537800",
	    "百色市": "533000",
	    "右江区": "533000",
	    "田东县": "531500",
	    "德保县": "533700",
	    "那坡县": "533900",
	    "乐业县": "533200",
	    "西林县": "533500",
	    "贺州市": "542800",
	    "八步区": "552106",
	    "钟山县": "542600",
	    "河池市": "547000",
	    "金城江区": "547000",
	    "天峨县": "547300",
	    "东兰县": "547400",
	    "环江毛南族自治县": "547100",
	    "都安瑶族自治县": "530700",
	    "来宾市": "546100",
	    "兴宾区": "546100",
	    "象州县": "545800",
	    "金秀瑶族自治县": "545700",
	    "崇左市": "532200",
	    "江洲区": "532200",
	    "宁明县": "532500",
	    "大新县": "532300",
	    "横县": "530300",
	    "青秀区": "530000",
	    "西乡塘区": "530000",
	    "邕宁区": "530200",
	    "隆安县": "532700",
	    "上林县": "530500",
	    "三江侗族自治县": "545500",
	    "鱼峰区": "545000",
	    "柳北区": "545000",
	    "柳城县": "545200",
	    "融安县": "545400",
	    "恭城瑶族自治县": "542500",
	    "叠彩区": "541000",
	    "七星区": "541000",
	    "阳朔县": "541900",
	    "灵川县": "541200",
	    "兴安县": "541300",
	    "灌阳县": "541600",
	    "资源县": "541400",
	    "荔蒲县": "546600",
	    "岑溪市": "543200",
	    "蝶山区": "543000",
	    "苍梧县": "543100",
	    "蒙山县": "546700",
	    "合浦县": "536100",
	    "银海区": "536000",
	    "东兴市": "538100",
	    "防城区": "538000",
	    "浦北县": "535300",
	    "钦北区": "535000",
	    "桂平市": "537200",
	    "港南区": "537100",
	    "平南县": "537300",
	    "北流市": "537400",
	    "容县": "537500",
	    "博白县": "537600",
	    "隆林各族自治县": "533500",
	    "田阳县": "533600",
	    "平果县": "531400",
	    "靖西县": "533800",
	    "凌云县": "533100",
	    "田林县": "533300",
	    "富川瑶族自治县": "542700",
	    "昭平县": "546800",
	    "宜州市": "546300",
	    "南丹县": "547200",
	    "凤山县": "547600",
	    "罗城仫佬族自治县": "546400",
	    "巴马瑶族自治县": "547500",
	    "大化瑶族自治县": "530800",
	    "合山市": "546500",
	    "忻城县": "546200",
	    "武宣县": "545900",
	    "凭祥市": "532600",
	    "扶绥县": "532100",
	    "龙州县": "532400",
	    "天等县": "532800",
	    "贵州省": "550000",
	    "贵阳市": "550000",
	    "南明区": "550000",
	    "花溪区": "550000",
	    "白云区": "550000",
	    "开阳县": "550300",
	    "修文县": "550200",
	    "六盘水市": "553000",
	    "钟山区": "553000",
	    "水城县": "553000",
	    "遵义市": "563000",
	    "红花岗区": "563000",
	    "遵义县": "563100",
	    "绥阳县": "563300",
	    "道真仡佬族苗族自治县": "563500",
	    "凤冈县": "564200",
	    "余庆县": "564400",
	    "赤水市": "564700",
	    "安顺市": "561000",
	    "西秀区": "561000",
	    "普定县": "562100",
	    "关岭布依族苗族自治县": "561300",
	    "铜仁地区": "554300",
	    "铜仁市": "554300",
	    "玉屏侗族自治县": "554000",
	    "思南县": "565100",
	    "德江县": "565200",
	    "松桃苗族自治县": "554100",
	    "黔西南布依族苗族自治州": "562400",
	    "兴义市": "562400",
	    "普安县": "561500",
	    "贞丰县": "562200",
	    "册亨县": "552200",
	    "毕节地区": "551700",
	    "毕节市": "551700",
	    "黔西县": "551500",
	    "织金县": "552100",
	    "威宁彝族回族苗族自治县": "553100",
	    "黔东南苗族侗族自治州": "556000",
	    "凯里市": "556000",
	    "施秉县": "556200",
	    "镇远县": "557700",
	    "天柱县": "556600",
	    "剑河县": "556400",
	    "黎平县": "557300",
	    "从江县": "557400",
	    "麻江县": "557600",
	    "黔南布依族苗族自治州": "558000",
	    "都匀市": "558000",
	    "荔波县": "558400",
	    "瓮安县": "550400",
	    "平塘县": "558300",
	    "长顺县": "550700",
	    "惠水县": "550600",
	    "清镇市": "551400",
	    "云岩区": "550000",
	    "乌当区": "550000",
	    "小河区": "550000",
	    "息烽县": "551100",
	    "盘县": "561600",
	    "六枝特区": "553400",
	    "仁怀市": "564500",
	    "汇川区": "563000",
	    "桐梓县": "563200",
	    "正安县": "563400",
	    "务川仡佬族苗族自治县": "564300",
	    "湄潭县": "564100",
	    "习水县": "564600",
	    "紫云苗族布依族自治县": "550800",
	    "平坝县": "561100",
	    "镇宁布依族苗族自治县": "561200",
	    "万山特区": "554200",
	    "江口县": "554400",
	    "石阡县": "555100",
	    "印江土家族苗族自治县": "555200",
	    "沿河土家族自治县": "565300",
	    "安龙县": "552400",
	    "兴仁县": "562300",
	    "晴隆县": "561400",
	    "望谟县": "552300",
	    "赫章县": "553200",
	    "大方县": "551600",
	    "金沙县": "551800",
	    "纳雍县": "553300",
	    "丹寨县": "557500",
	    "黄平县": "556100",
	    "三穗县": "556500",
	    "岑巩县": "557800",
	    "锦屏县": "556700",
	    "台江县": "556300",
	    "榕江县": "557200",
	    "雷山县": "557100",
	    "三都水族自治县": "558100",
	    "福泉市": "550500",
	    "贵定县": "551300",
	    "独山县": "558200",
	    "罗甸县": "550100",
	    "龙里县": "551200",
	    "云南省": "650000",
	    "昆明市": "650000",
	    "五华区": "650000",
	    "官渡区": "650200",
	    "东川区": "654100",
	    "晋宁县": "650600",
	    "宜良县": "652100",
	    "嵩明县": "651700",
	    "寻甸回族彝族自治县": "655200",
	    "曲靖市": "655000",
	    "麒麟区": "655000",
	    "陆良县": "655600",
	    "罗平县": "655800",
	    "会泽县": "654200",
	    "玉溪市": "653100",
	    "红塔区": "653100",
	    "澄江县": "652500",
	    "华宁县": "652800",
	    "峨山彝族自治县": "653200",
	    "保山市": "678000",
	    "隆阳区": "678000",
	    "腾冲县": "679100",
	    "昭通市": "657000",
	    "昭阳区": "657000",
	    "巧家县": "654600",
	    "大关县": "657400",
	    "绥江县": "657700",
	    "彝良县": "657600",
	    "丽江市": "674100",
	    "古城区": "674100",
	    "永胜县": "674200",
	    "思茅市": "665000",
	    "翠云区": "665000",
	    "墨江哈尼族自治县": "654800",
	    "景谷傣族彝族自治县": "666400",
	    "江城哈尼族彝族自治县": "665900",
	    "澜沧拉祜族自治县": "665600",
	    "临沧市": "677000",
	    "临翔区": "677000",
	    "云县": "675800",
	    "镇康县": "677700",
	    "耿马傣族佤族自治县": "677500",
	    "楚雄彝族自治州": "675000",
	    "楚雄市": "675000",
	    "牟定县": "675500",
	    "姚安县": "675300",
	    "永仁县": "651400",
	    "武定县": "651600",
	    "红河哈尼族彝族自治州": "661400",
	    "个旧市": "661000",
	    "蒙自县": "661100",
	    "建水县": "654300",
	    "弥勒县": "652300",
	    "元阳县": "662400",
	    "金平苗族瑶族傣族自治县": "661500",
	    "文山壮族苗族自治州": "663000",
	    "文山县": "663000",
	    "西畴县": "663500",
	    "马关县": "663700",
	    "广南县": "663300",
	    "西双版纳傣族自治州": "666100",
	    "景洪市": "666100",
	    "大理白族自治州": "671000",
	    "大理市": "671000",
	    "祥云县": "672100",
	    "弥渡县": "675600",
	    "巍山彝族回族自治县": "672400",
	    "云龙县": "672700",
	    "剑川县": "671300",
	    "德宏傣族景颇族自治州": "678400",
	    "瑞丽市": "678600",
	    "梁河县": "679200",
	    "怒江傈僳族自治州": "673100",
	    "泸水县": "673200",
	    "贡山独龙族怒族自治县": "673500",
	    "迪庆藏族自治州": "674400",
	    "香格里拉县": "674400",
	    "盘龙区": "650000",
	    "西山区": "650100",
	    "呈贡县": "650500",
	    "富民县": "650400",
	    "石林彝族自治县": "652200",
	    "禄劝彝族苗族自治县": "651500",
	    "安宁市": "650300",
	    "马龙县": "655100",
	    "师宗县": "655700",
	    "富源县": "655500",
	    "沾益县": "655500",
	    "宣威市": "655400",
	    "元江哈尼族彝族傣族自治县": "653300",
	    "江川县": "652600",
	    "通海县": "652700",
	    "易门县": "651100",
	    "新平彝族傣族自治县": "653400",
	    "昌宁县": "678100",
	    "施甸县": "678200",
	    "龙陵县": "678300",
	    "水富县": "657800",
	    "鲁甸县": "657100",
	    "盐津县": "657500",
	    "永善县": "657300",
	    "镇雄县": "657200",
	    "威信县": "657900",
	    "宁蒗彝族自治县": "674300",
	    "玉龙纳西族自治县": "674100",
	    "华坪县": "674800",
	    "西盟佤族自治县": "665700",
	    "普洱哈尼族彝族自治县": "665100",
	    "景东彝族自治县": "676200",
	    "镇沅彝族哈尼族拉祜族自治县": "666500",
	    "孟连傣族拉祜族佤族自治县": "665800",
	    "沧源佤族自治县": "677400",
	    "凤庆县": "675900",
	    "永德县": "677600",
	    "双江拉祜族佤族布朗族傣族自治县": "677300",
	    "禄丰县": "651200",
	    "双柏县": "675100",
	    "南华县": "675200",
	    "大姚县": "675400",
	    "元谋县": "651300",
	    "河口瑶族自治县": "661300",
	    "开远市": "661600",
	    "屏边苗族自治县": "661200",
	    "石屏县": "662200",
	    "泸西县": "652400",
	    "红河县": "654400",
	    "绿春县": "662500",
	    "富宁县": "663400",
	    "砚山县": "663100",
	    "麻栗坡县": "663600",
	    "丘北县": "663200",
	    "勐腊县": "666300",
	    "勐海县": "666200",
	    "鹤庆县": "671500",
	    "漾濞彝族自治县": "672500",
	    "宾川县": "671600",
	    "南涧彝族自治县": "675700",
	    "永平县": "672600",
	    "洱源县": "671200",
	    "陇川县": "678700",
	    "潞西市": "678400",
	    "盈江县": "679300",
	    "维西傈僳族自治县": "674600",
	    "福贡县": "673400",
	    "兰坪白族普米族自治县": "671400",
	    "德钦县": "674500",
	    "河北省": "050000",
	    "石家庄市": "050000",
	    "长安区": "050000",
	    "桥西区": "050000",
	    "井陉矿区": "050100",
	    "井陉县": "050300",
	    "栾城县": "051430",
	    "灵寿县": "050500",
	    "深泽县": "052500",
	    "无极县": "052400",
	    "元氏县": "051130",
	    "辛集市": "052300",
	    "晋州市": "052200",
	    "唐山市": "063000",
	    "路南区": "063000",
	    "古冶区": "063100",
	    "丰南区": "063300",
	    "滦县": "063700",
	    "乐亭县": "063600",
	    "玉田县": "064100",
	    "遵化市": "064200",
	    "秦皇岛市": "066000",
	    "海港区": "066000",
	    "北戴河区": "066100",
	    "昌黎县": "066600",
	    "邯郸市": "056000",
	    "邯山区": "056000",
	    "复兴区": "056000",
	    "邯郸县": "056000",
	    "成安县": "056700",
	    "涉县": "056400",
	    "肥乡县": "057550",
	    "邱县": "057450",
	    "广平县": "057650",
	    "魏县": "056800",
	    "邢台市": "054000",
	    "桥东区": "054000",
	    "邢台县": "054000",
	    "内丘县": "054200",
	    "隆尧县": "055350",
	    "南和县": "054400",
	    "巨鹿县": "055250",
	    "广宗县": "054600",
	    "威县": "054700",
	    "临西县": "054900",
	    "保定市": "071000",
	    "新市区": "071000",
	    "南市区": "071000",
	    "清苑县": "071100",
	    "阜平县": "073200",
	    "定兴县": "072650",
	    "高阳县": "071500",
	    "涞源县": "102900",
	    "安新县": "071600",
	    "曲阳县": "073100",
	    "顺平县": "072250",
	    "雄县": "071800",
	    "定州市": "073000",
	    "张家口市": "075000",
	    "桥东区": "075000",
	    "宣化区": "075000",
	    "宣化县": "075100",
	    "康保县": "076650",
	    "尚义县": "076750",
	    "阳原县": "075800",
	    "万全县": "076250",
	    "涿鹿县": "075600",
	    "承德市": "067000",
	    "双桥区": "067000",
	    "鹰手营子矿区": "067200",
	    "兴隆县": "067300",
	    "滦平县": "068250",
	    "丰宁满族自治县": "068350",
	    "沧州市": "061000",
	    "新华区": "061000",
	    "沧县": "061000",
	    "东光县": "061600",
	    "盐山县": "061300",
	    "南皮县": "061500",
	    "献县": "062250",
	    "泊头市": "062150",
	    "黄骅市": "061100",
	    "廊坊市": "065000",
	    "安次区": "065000",
	    "固安县": "065500",
	    "香河县": "065400",
	    "文安县": "065800",
	    "霸州市": "065700",
	    "衡水市": "053000",
	    "桃城区": "053000",
	    "武邑县": "053400",
	    "饶阳县": "053900",
	    "故城县": "053800",
	    "阜城县": "053700",
	    "鹿泉市": "050200",
	    "桥东区": "050000",
	    "新华区": "050000",
	    "裕华区": "050000",
	    "正定县": "050800",
	    "行唐县": "050600",
	    "高邑县": "051330",
	    "赞皇县": "051230",
	    "平山县": "050400",
	    "赵县": "051530",
	    "藁城市": "052160",
	    "新乐市": "050700",
	    "路北区": "063000",
	    "开平区": "063000",
	    "丰润区": "063000",
	    "滦南县": "063500",
	    "迁西县": "064300",
	    "唐海县": "063200",
	    "迁安市": "064400",
	    "卢龙县": "066400",
	    "山海关区": "066200",
	    "青龙满族自治县": "066500",
	    "抚宁县": "066300",
	    "武安市": "056300",
	    "丛台区": "056000",
	    "峰峰矿区": "056200",
	    "临漳县": "056600",
	    "大名县": "056900",
	    "磁县": "056500",
	    "永年县": "057150",
	    "鸡泽县": "057350",
	    "馆陶县": "057750",
	    "曲周县": "057250",
	    "沙河市": "054100",
	    "桥西区": "054000",
	    "临城县": "054300",
	    "柏乡县": "055450",
	    "任县": "055150",
	    "宁晋县": "055550",
	    "新河县": "051730",
	    "平乡县": "054500",
	    "清河县": "054800",
	    "南宫市": "051800",
	    "高碑店市": "074000",
	    "北市区": "071000",
	    "满城县": "072150",
	    "涞水县": "074100",
	    "徐水县": "072550",
	    "唐县": "072350",
	    "容城县": "071700",
	    "望都县": "072450",
	    "易县": "074200",
	    "蠡县": "071400",
	    "博野县": "071300",
	    "涿州市": "072750",
	    "安国市": "071200",
	    "崇礼县": "076350",
	    "桥西区": "075000",
	    "下花园区": "075300",
	    "张北县": "076450",
	    "沽源县": "076550",
	    "蔚县": "075700",
	    "怀安县": "076150",
	    "怀来县": "075400",
	    "赤城县": "075500",
	    "围场满族蒙古族自治县": "068450",
	    "双滦区": "067000",
	    "承德县": "067400",
	    "平泉县": "067500",
	    "隆化县": "068150",
	    "宽城满族自治县": "067600",
	    "运河区": "061000",
	    "青县": "062650",
	    "海兴县": "061200",
	    "肃宁县": "062350",
	    "吴桥县": "061800",
	    "孟村回族自治县": "061400",
	    "任丘市": "062550",
	    "河间市": "062450",
	    "广阳区": "065000",
	    "永清县": "065600",
	    "大城县": "065900",
	    "大厂回族自治县": "065300",
	    "三河市": "065200",
	    "深州市": "052800",
	    "枣强县": "053100",
	    "武强县": "053300",
	    "安平县": "053600",
	    "景县": "053500",
	    "冀州市": "053200",
	    "河南省": "450000",
	    "郑州市": "450000",
	    "中原区": "450000",
	    "管城回族区": "450000",
	    "上街区": "450041",
	    "中牟县": "451450",
	    "荥阳市": "450100",
	    "新郑市": "451100",
	    "开封市": "475000",
	    "龙亭区": "475000",
	    "鼓楼区": "475000",
	    "郊区": "475000",
	    "通许县": "452200",
	    "开封县": "475100",
	    "洛阳市": "471000",
	    "老城区": "471000",
	    "廛河回族区": "471000",
	    "吉利区": "471000",
	    "孟津县": "471100",
	    "栾川县": "471500",
	    "汝阳县": "471200",
	    "洛宁县": "471700",
	    "平顶山市": "467000",
	    "新华区": "467000",
	    "石龙区": "467000",
	    "宝丰县": "467400",
	    "鲁山县": "467300",
	    "舞钢市": "462500",
	    "安阳市": "455000",
	    "文峰区": "455000",
	    "殷都区": "455000",
	    "安阳县": "455100",
	    "滑县": "456400",
	    "鹤壁市": "458000",
	    "鹤山区": "458000",
	    "淇滨区": "458000",
	    "新乡市": "453000",
	    "红旗区": "453000",
	    "获嘉县": "453800",
	    "延津县": "453200",
	    "长垣县": "453400",
	    "焦作市": "454150",
	    "解放区": "454150",
	    "马村区": "454150",
	    "修武县": "454350",
	    "武陟县": "454950",
	    "济源市": "454650",
	    "濮阳市": "457000",
	    "清丰县": "457300",
	    "范县": "457500",
	    "许昌市": "461000",
	    "魏都区": "461000",
	    "鄢陵县": "461200",
	    "禹州市": "452570",
	    "漯河市": "462000",
	    "源汇区": "462000",
	    "召陵区": "462300",
	    "三门峡市": "472000",
	    "湖滨区": "472000",
	    "陕县": "472100",
	    "义马市": "472300",
	    "南阳市": "473000",
	    "宛城区": "473000",
	    "南召县": "474650",
	    "西峡县": "474550",
	    "内乡县": "474350",
	    "社旗县": "473300",
	    "新野县": "473500",
	    "商丘市": "476000",
	    "梁园区": "476000",
	    "民权县": "476800",
	    "宁陵县": "476700",
	    "虞城县": "476300",
	    "信阳市": "464000",
	    "师河区": "464000",
	    "罗山县": "464200",
	    "新县": "465500",
	    "固始县": "465200",
	    "淮滨县": "464400",
	    "周口市": "466000",
	    "川汇区": "466000",
	    "西华县": "466600",
	    "沈丘县": "466300",
	    "淮阳县": "466700",
	    "鹿邑县": "477200",
	    "驻马店市": "463000",
	    "驿城区": "463000",
	    "上蔡县": "463800",
	    "正阳县": "463600",
	    "泌阳县": "463700",
	    "遂平县": "463100",
	    "登封市": "452470",
	    "二七区": "450000",
	    "金水区": "450000",
	    "邙山区": "450000",
	    "巩义市": "452100",
	    "新密市": "452370",
	    "兰考县": "475300",
	    "顺河回族区": "475000",
	    "南关区": "475000",
	    "杞县": "475200",
	    "尉氏县": "452100",
	    "偃师市": "471900",
	    "西工区": "471000",
	    "涧西区": "471000",
	    "洛龙区": "471000",
	    "新安县": "471800",
	    "嵩县": "471400",
	    "宜阳县": "471600",
	    "伊川县": "471300",
	    "汝州市": "467500",
	    "卫东区": "467000",
	    "湛河区": "467000",
	    "叶县": "467200",
	    "郏县": "467100",
	    "林州市": "456500",
	    "林州市": "456500",
	    "北关区": "455000",
	    "龙安区": "455000",
	    "汤阴县": "456150",
	    "内黄县": "456300",
	    "淇县": "456750",
	    "山城区": "458000",
	    "浚县": "456250",
	    "辉县市": "453600",
	    "新乡县": "453700",
	    "原阳县": "453500",
	    "封丘县": "453300",
	    "卫辉市": "453100",
	    "孟州市": "454750",
	    "中站区": "454150",
	    "山阳区": "454150",
	    "博爱县": "454450",
	    "温县": "454850",
	    "沁阳市": "454550",
	    "濮阳县": "457100",
	    "南乐县": "457400",
	    "台前县": "457600",
	    "长葛市": "461500",
	    "许昌县": "461100",
	    "襄城县": "452670",
	    "临颍县": "462600",
	    "郾城区": "462300",
	    "舞阳县": "462400",
	    "灵宝市": "472500",
	    "渑池县": "472400",
	    "卢氏县": "472200",
	    "邓州市": "474150",
	    "卧龙区": "473000",
	    "方城县": "473200",
	    "镇平县": "474250",
	    "淅川县": "474450",
	    "唐河县": "473400",
	    "桐柏县": "474750",
	    "永城市": "476600",
	    "睢阳区": "476000",
	    "睢县": "476900",
	    "柘城县": "476200",
	    "夏邑县": "476400",
	    "息县": "464300",
	    "平桥区": "464000",
	    "光山县": "465450",
	    "商城县": "465350",
	    "潢川县": "465150",
	    "项城市": "466200",
	    "扶沟县": "461300",
	    "商水县": "466100",
	    "郸城县": "477150",
	    "太康县": "475400",
	    "新蔡县": "463500",
	    "西平县": "463900",
	    "平舆县": "463400",
	    "确山县": "463200",
	    "汝南县": "463300",
	    "湖北省": "430000",
	    "武汉市": "430000",
	    "江岸区": "430014",
	    "乔口区": "430000",
	    "武昌区": "430000",
	    "洪山区": "430070",
	    "汉南区": "430090",
	    "江夏区": "430200",
	    "黄石市": "435000",
	    "黄石港区": "435000",
	    "铁山区": "435000",
	    "十堰市": "442000",
	    "茅箭区": "442000",
	    "郧县": "442500",
	    "竹山县": "442200",
	    "房县": "442100",
	    "宜昌市": "443000",
	    "西陵区": "443000",
	    "点军区": "443000",
	    "夷陵区": "443100",
	    "兴山县": "443700",
	    "长阳土家族自治县": "443500",
	    "宜都市": "443000",
	    "襄樊市": "441000",
	    "襄城区": "441000",
	    "襄阳区": "441100",
	    "谷城县": "441700",
	    "老河口市": "441800",
	    "鄂州市": "436000",
	    "梁子湖区": "436000",
	    "荆门市": "448000",
	    "东宝区": "448000",
	    "京山县": "431800",
	    "孝感市": "432000",
	    "孝南区": "432100",
	    "大悟县": "432800",
	    "应城市": "432400",
	    "荆州市": "434000",
	    "沙市区": "434000",
	    "公安县": "434300",
	    "江陵县": "434100",
	    "洪湖市": "433200",
	    "黄冈市": "438000",
	    "黄州区": "438000",
	    "红安县": "438400",
	    "英山县": "438700",
	    "蕲春县": "435300",
	    "麻城市": "438300",
	    "咸宁市": "437000",
	    "咸安区": "437000",
	    "通城县": "437400",
	    "通山县": "437600",
	    "随州市": "441300",
	    "曾都区": "441300",
	    "恩施土家族苗族自治州": "445000",
	    "恩施市": "445000",
	    "建始县": "445300",
	    "宣恩县": "445500",
	    "来凤县": "445700",
	    "仙桃市": "433000",
	    "天门市": "431700",
	    "新洲区": "431400",
	    "江汉区": "430000",
	    "汉阳区": "430050",
	    "青山区": "430080",
	    "东西湖区": "430040",
	    "蔡甸区": "430100",
	    "黄陂区": "432200",
	    "大冶市": "435100",
	    "下陆区": "435000",
	    "阳新县": "435200",
	    "丹江口市": "442700",
	    "张湾区": "442000",
	    "郧西县": "442600",
	    "竹溪县": "442300",
	    "枝江市": "443200",
	    "伍家岗区": "443000",
	    "虎亭区": "443000",
	    "远安县": "444200",
	    "秭归县": "443600",
	    "五峰土家族自治县": "443400",
	    "当阳市": "444100",
	    "宜城市": "441400",
	    "樊城区": "441000",
	    "南漳县": "441500",
	    "保康县": "441600",
	    "枣阳市": "441200",
	    "鄂城区": "436000",
	    "华容区": "436000",
	    "钟祥市": "431900",
	    "掇刀区": "448000",
	    "沙洋县": "448200",
	    "汉川市": "432300",
	    "孝昌县": "432900",
	    "云梦县": "432500",
	    "安陆市": "432600",
	    "松滋市": "434200",
	    "荆州区": "434020",
	    "监利县": "433300",
	    "石首市": "434400",
	    "武穴市": "435400",
	    "团风县": "438000",
	    "罗田县": "438600",
	    "浠水县": "438200",
	    "黄梅县": "435500",
	    "赤壁市": "437300",
	    "嘉鱼县": "437200",
	    "崇阳县": "437500",
	    "广水市": "432700",
	    "鹤峰县": "445800",
	    "利川市": "445400",
	    "巴东县": "444300",
	    "咸丰县": "445600",
	    "潜江市": "433100",
	    "神农架林区": "442400",
	    "湖南省": "410000",
	    "长沙市": "410000",
	    "芙蓉区": "410000",
	    "岳麓区": "410000",
	    "雨花区": "410000",
	    "望城县": "410200",
	    "株洲市": "412000",
	    "荷塘区": "412000",
	    "石峰区": "412000",
	    "株洲县": "412000",
	    "茶陵县": "412400",
	    "湘潭市": "411100",
	    "雨湖区": "411100",
	    "湘潭县": "411200",
	    "衡阳市": "421000",
	    "珠晖区": "421000",
	    "石鼓区": "421000",
	    "南岳区": "421000",
	    "衡南县": "421100",
	    "衡东县": "421400",
	    "耒阳市": "421800",
	    "邵阳市": "422000",
	    "双清区": "422000",
	    "北塔区": "422000",
	    "新邵县": "422900",
	    "隆回县": "422200",
	    "绥宁县": "422600",
	    "城步苗族自治县": "422500",
	    "岳阳市": "414000",
	    "岳阳楼区": "414000",
	    "君山区": "414000",
	    "华容县": "414200",
	    "平江县": "410400",
	    "常德市": "415000",
	    "武陵区": "415000",
	    "安乡县": "415600",
	    "澧县": "415500",
	    "桃源县": "415700",
	    "张家界市": "427000",
	    "永定区": "427000",
	    "慈利县": "427200",
	    "益阳市": "413000",
	    "资阳区": "413000",
	    "南县": "413200",
	    "安化县": "413500",
	    "郴州市": "423000",
	    "北湖区": "423000",
	    "桂阳县": "424400",
	    "永兴县": "423300",
	    "临武县": "424300",
	    "桂东县": "423500",
	    "永州市": "425000",
	    "芝山区": "425000",
	    "祁阳县": "421700",
	    "双牌县": "425200",
	    "江永县": "425400",
	    "蓝山县": "425800",
	    "怀化市": "418000",
	    "鹤城区": "418000",
	    "沅陵县": "419600",
	    "溆浦县": "419300",
	    "麻阳苗族自治县": "419400",
	    "芷江侗族自治县": "419100",
	    "通道侗族自治县": "418500",
	    "娄底市": "417000",
	    "娄星区": "417000",
	    "新化县": "417600",
	    "湘西土家族苗族自治州": "416000",
	    "吉首市": "416000",
	    "凤凰县": "416200",
	    "保靖县": "416500",
	    "永顺县": "416700",
	    "浏阳市": "410300",
	    "天心区": "410000",
	    "开福区": "410000",
	    "长沙县": "410100",
	    "宁乡县": "410600",
	    "醴陵市": "412200",
	    "芦淞区": "412000",
	    "天元区": "412000",
	    "攸县": "412300",
	    "炎陵县": "412500",
	    "韶山市": "411300",
	    "岳塘区": "411100",
	    "湘乡市": "411400",
	    "常宁市": "421500",
	    "雁峰区": "421000",
	    "蒸湘区": "421000",
	    "衡阳县": "421200",
	    "衡山县": "421300",
	    "祁东县": "421600",
	    "武冈市": "422400",
	    "大祥区": "422000",
	    "邵东县": "422800",
	    "邵阳县": "422100",
	    "洞口县": "422300",
	    "新宁县": "422700",
	    "临湘市": "414300",
	    "云溪区": "414000",
	    "岳阳县": "414100",
	    "湘阴县": "410500",
	    "汨罗市": "414400",
	    "津市市": "415400",
	    "鼎城区": "415100",
	    "汉寿县": "415900",
	    "临澧县": "415200",
	    "石门县": "415300",
	    "桑植县": "427100",
	    "武陵源区": "427400",
	    "沅江市": "413100",
	    "赫山区": "413000",
	    "桃江县": "413400",
	    "资兴市": "423400",
	    "苏仙区": "423000",
	    "宜章县": "424200",
	    "嘉禾县": "424500",
	    "汝城县": "424100",
	    "安仁县": "423600",
	    "江华瑶族自治县": "425500",
	    "冷水滩区": "425000",
	    "东安县": "425900",
	    "道县": "425300",
	    "宁远县": "425600",
	    "新田县": "425700",
	    "洪江市": "418200",
	    "中方县": "418000",
	    "辰溪县": "419500",
	    "会同县": "418300",
	    "新晃侗族自治县": "419200",
	    "靖州苗族侗族自治县": "418400",
	    "涟源市": "417100",
	    "双峰县": "417700",
	    "冷水江市": "417500",
	    "龙山县": "416800",
	    "泸溪县": "416100",
	    "花垣县": "416400",
	    "古丈县": "416300",
	    "江苏省": "210000",
	    "南京市": "210000",
	    "玄武区": "210000",
	    "秦淮区": "210000",
	    "鼓楼区": "210000",
	    "浦口区": "210000",
	    "雨花台区": "210000",
	    "六合区": "211500",
	    "无锡市": "214000",
	    "崇安区": "214000",
	    "北塘区": "214000",
	    "惠山区": "214000",
	    "徐州市": "221000",
	    "鼓楼区": "221000",
	    "九里区": "221000",
	    "泉山区": "221000",
	    "沛县": "221600",
	    "睢宁县": "221200",
	    "常州市": "213000",
	    "天宁区": "213000",
	    "戚墅堰区": "213000",
	    "溧阳市": "213300",
	    "苏州市": "215000",
	    "沧浪区": "215000",
	    "金阊区": "215000",
	    "吴中区": "215100",
	    "常熟市": "215500",
	    "昆山市": "215300",
	    "南通市": "226000",
	    "崇川区": "226000",
	    "海安县": "226600",
	    "启东市": "226200",
	    "通州市": "226300",
	    "连云港市": "222000",
	    "连云区": "222000",
	    "海州区": "222000",
	    "东海县": "222300",
	    "淮安市": "223001",
	    "清河区": "223001",
	    "淮阴区": "223300",
	    "涟水县": "223400",
	    "盱眙县": "211700",
	    "盐城市": "224000",
	    "盐都区": "224000",
	    "滨海县": "224000",
	    "射阳县": "224300",
	    "东台市": "224200",
	    "扬州市": "225000",
	    "广陵区": "225000",
	    "宝应县": "225800",
	    "高邮市": "225600",
	    "镇江市": "212000",
	    "京口区": "212000",
	    "丹徒区": "212100",
	    "扬中市": "212200",
	    "泰州市": "225300",
	    "海陵区": "225300",
	    "兴化市": "225700",
	    "泰兴市": "225400",
	    "宿迁市": "223800",
	    "宿城区": "223800",
	    "沭阳县": "223600",
	    "高淳县": "211300",
	    "白下区": "210000",
	    "建邺区": "210000",
	    "下关区": "210000",
	    "栖霞区": "210000",
	    "江宁区": "211100",
	    "溧水县": "211200",
	    "宜兴市": "214200",
	    "南长区": "214000",
	    "锡山区": "214000",
	    "江阴市": "214400",
	    "邳州市": "221300",
	    "云龙区": "221000",
	    "贾汪区": "221000",
	    "丰县": "221700",
	    "铜山县": "221100",
	    "新沂市": "221400",
	    "金坛市": "213200",
	    "钟楼区": "213000",
	    "武进区": "213100",
	    "太仓市": "215400",
	    "平江区": "215000",
	    "虎丘区": "215000",
	    "相城区": "215100",
	    "张家港市": "215600",
	    "吴江市": "215200",
	    "海门市": "226100",
	    "港闸区": "226000",
	    "如东县": "226400",
	    "如皋市": "226500",
	    "灌南县": "223500",
	    "新浦区": "222000",
	    "赣榆县": "222100",
	    "灌云县": "222200",
	    "金湖县": "211600",
	    "楚州区": "223200",
	    "清浦区": "223001",
	    "洪泽县": "223100",
	    "大丰市": "224100",
	    "响水县": "224600",
	    "阜宁县": "224400",
	    "建湖县": "224700",
	    "亭湖区": "224002",
	    "江都市": "225200",
	    "邗江区": "225100",
	    "仪征市": "211400",
	    "句容市": "212400",
	    "润州区": "212000",
	    "丹阳市": "212300",
	    "姜堰市": "225500",
	    "高港区": "225300",
	    "靖江市": "214500",
	    "泗洪县": "223900",
	    "宿豫区": "223800",
	    "泗阳县": "223700",
	    "江西省": "330000",
	    "南昌市": "330000",
	    "东湖区": "330000",
	    "青云谱区": "330000",
	    "南昌县": "330200",
	    "安义县": "330500",
	    "景德镇市": "333000",
	    "昌江区": "333000",
	    "浮梁县": "333400",
	    "萍乡市": "337000",
	    "安源区": "337000",
	    "莲花县": "337100",
	    "九江市": "332000",
	    "庐山区": "332900",
	    "九江县": "332100",
	    "修水县": "332400",
	    "德安县": "330400",
	    "都昌县": "332600",
	    "彭泽县": "332700",
	    "新余市": "336500",
	    "渝水区": "336500",
	    "鹰潭市": "335000",
	    "月湖区": "335000",
	    "赣州市": "341000",
	    "章贡区": "341000",
	    "信丰县": "341600",
	    "上犹县": "341200",
	    "安远县": "342100",
	    "定南县": "341900",
	    "宁都县": "342800",
	    "兴国县": "342400",
	    "寻乌县": "342200",
	    "瑞金市": "342500",
	    "吉安市": "343000",
	    "吉州区": "343000",
	    "吉安县": "343100",
	    "峡江县": "331400",
	    "永丰县": "331500",
	    "遂川县": "343900",
	    "安福县": "343200",
	    "宜春市": "336000",
	    "袁州区": "336000",
	    "万载县": "336100",
	    "宜丰县": "336300",
	    "铜鼓县": "336200",
	    "樟树市": "331200",
	    "抚州市": "344000",
	    "临川区": "344100",
	    "黎川县": "344600",
	    "崇仁县": "344200",
	    "宜黄县": "344400",
	    "资溪县": "335300",
	    "上饶市": "334000",
	    "信州区": "334000",
	    "广丰县": "334600",
	    "铅山县": "334500",
	    "弋阳县": "334400",
	    "鄱阳县": "333100",
	    "婺源县": "333200",
	    "进贤县": "331700",
	    "西湖区": "330000",
	    "湾里区": "330000",
	    "新建县": "330100",
	    "乐平市": "333300",
	    "珠山区": "333000",
	    "芦溪县": "337000",
	    "湘东区": "337000",
	    "上栗县": "337000",
	    "瑞昌市": "332200",
	    "浔阳区": "332000",
	    "武宁县": "332300",
	    "永修县": "330300",
	    "星子县": "332800",
	    "湖口县": "332500",
	    "分宜县": "336600",
	    "贵溪市": "335400",
	    "余江县": "335200",
	    "南康市": "341400",
	    "赣县": "341100",
	    "大余县": "341500",
	    "崇义县": "341300",
	    "龙南县": "341700",
	    "全南县": "341800",
	    "于都县": "342300",
	    "会昌县": "342600",
	    "石城县": "342700",
	    "井冈山市": "343600",
	    "青原区": "343000",
	    "吉水县": "331600",
	    "新干县": "331300",
	    "泰和县": "343700",
	    "万安县": "343800",
	    "永新县": "343400",
	    "高安市": "330800",
	    "奉新县": "330700",
	    "上高县": "336400",
	    "靖安县": "330600",
	    "丰城市": "331100",
	    "广昌县": "344900",
	    "南城县": "344700",
	    "南丰县": "344500",
	    "乐安县": "344300",
	    "金溪县": "344800",
	    "东乡县": "331800",
	    "德兴市": "334200",
	    "上饶县": "334100",
	    "玉山县": "334700",
	    "横峰县": "334300",
	    "余干县": "335100",
	    "万年县": "335500",
	    "四川省": "610000",
	    "成都市": "610000",
	    "锦江区": "610000",
	    "金牛区": "610000",
	    "成华区": "610000",
	    "青白江区": "610300",
	    "金堂县": "610400",
	    "温江县": "611100",
	    "大邑县": "611300",
	    "新津县": "611400",
	    "彭州市": "610000",
	    "自贡市": "643000",
	    "自流井区": "643000",
	    "大安区": "643010",
	    "荣县": "643100",
	    "攀枝花市": "617000",
	    "东区": "617000",
	    "仁和区": "617000",
	    "泸州市": "646000",
	    "江阳区": "646000",
	    "龙马潭区": "646000",
	    "合江县": "646200",
	    "德阳市": "618000",
	    "旌阳区": "618000",
	    "罗江县": "618500",
	    "什邡市": "618400",
	    "绵阳市": "621000",
	    "涪城区": "621000",
	    "三台县": "621100",
	    "安县": "622650",
	    "平武县": "622550",
	    "广元市": "628000",
	    "市中区": "628000",
	    "朝天区": "628000",
	    "青川县": "628100",
	    "遂宁市": "629000",
	    "船山区": "629000",
	    "蓬溪县": "629100",
	    "内江市": "641000",
	    "市中区": "641000",
	    "威远县": "642450",
	    "乐山市": "614000",
	    "市中区": "614000",
	    "五通桥区": "614800",
	    "犍为县": "614400",
	    "夹江县": "614100",
	    "峨边彝族自治县": "614300",
	    "南充市": "637000",
	    "顺庆区": "637000",
	    "嘉陵区": "637500",
	    "营山县": "637700",
	    "仪陇县": "637600",
	    "眉山市": "620000",
	    "东坡区": "620000",
	    "彭山县": "620800",
	    "丹棱县": "620200",
	    "宜宾市": "644000",
	    "翠屏区": "644000",
	    "南溪县": "644100",
	    "长宁县": "644300",
	    "珙县": "644500",
	    "兴文县": "644400",
	    "广安市": "638500",
	    "广安区": "638550",
	    "武胜县": "638400",
	    "达州市": "635000",
	    "通川区": "635000",
	    "宣汉县": "636150",
	    "大竹县": "635100",
	    "雅安市": "625000",
	    "雨城区": "625000",
	    "荥经县": "625200",
	    "石棉县": "625400",
	    "芦山县": "625600",
	    "巴中市": "636600",
	    "巴州区": "636600",
	    "南江县": "635600",
	    "资阳市": "641300",
	    "雁江区": "641300",
	    "乐至县": "641500",
	    "阿坝藏族羌族自治州": "624000",
	    "汶川县": "623000",
	    "茂县": "623200",
	    "九寨沟县": "623400",
	    "小金县": "624200",
	    "马尔康县": "624000",
	    "阿坝县,": "624600",
	    "甘孜藏族自治州": "626000",
	    "康定县": "626000",
	    "丹巴县": "626300",
	    "雅江县": "627450",
	    "炉霍县": "626500",
	    "新龙县": "626800",
	    "白玉县": "627150",
	    "色达县": "626600",
	    "巴塘县": "627650",
	    "得荣县": "627950",
	    "凉山彝族自治州": "615000",
	    "西昌市": "615000",
	    "盐源县": "615700",
	    "会理县": "615100",
	    "宁南县": "615400",
	    "布拖县": "615350",
	    "昭觉县": "616150",
	    "冕宁县": "615600",
	    "甘洛县": "616850",
	    "崇州市": "611200",
	    "青羊区": "610000",
	    "武侯区": "610000",
	    "龙泉驿区": "610100",
	    "新都区": "610500",
	    "双流县": "610200",
	    "郫县": "611700",
	    "蒲江县": "611600",
	    "都江堰市": "611800",
	    "邛崃市": "611500",
	    "富顺县": "643200",
	    "贡井区": "643020",
	    "沿滩区": "643030",
	    "盐边县": "617100",
	    "西区": "617000",
	    "米易县": "617200",
	    "古蔺县": "646500",
	    "纳溪区": "646300",
	    "泸县": "646100",
	    "叙永县": "646400",
	    "绵竹市": "618200",
	    "中江县": "618300",
	    "广汉市": "618300",
	    "江油市": "621700",
	    "游仙区": "621000",
	    "盐亭县": "621600",
	    "梓潼县": "622150",
	    "苍溪县": "628400",
	    "元坝区": "628000",
	    "旺苍县": "628200",
	    "剑阁县": "628300",
	    "大英县": "629300",
	    "安居区": "629000",
	    "射洪县": "629200",
	    "隆昌县": "642150",
	    "东兴区": "641100",
	    "资中县": "641200",
	    "峨眉山市": "614200",
	    "沙湾区": "614900",
	    "金口河区": "614700",
	    "井研县": "613100",
	    "沐川县": "614500",
	    "马边彝族自治县": "614600",
	    "阆中市": "637400",
	    "高坪区": "637100",
	    "南部县": "637300",
	    "蓬安县": "637800",
	    "西充县": "637200",
	    "青神县": "620400",
	    "仁寿县": "620500",
	    "洪雅县": "620300",
	    "屏山县": "645350",
	    "宜宾县": "644600",
	    "江安县": "644200",
	    "高县": "645150",
	    "筠连县": "645250",
	    "华莹市": "638600",
	    "岳池县": "638300",
	    "邻水县": "638500",
	    "万源市": "636350",
	    "达县": "635000",
	    "开江县": "636250",
	    "渠县": "635200",
	    "宝兴县": "625700",
	    "名山县": "625100",
	    "汉源县": "625300",
	    "天全县": "625500",
	    "平昌县": "636400",
	    "通江县": "636700",
	    "简阳市": "641400",
	    "安岳县": "642350",
	    "红原县": "624400",
	    "理县": "623100",
	    "松潘县": "623300",
	    "金川县": "624100",
	    "黑水县": "623500",
	    "壤塘县": "624300",
	    "若尔盖县": "624500",
	    "稻城县": "627750",
	    "泸定县": "626100",
	    "九龙县": "616200",
	    "道孚县": "626400",
	    "甘孜县": "626700",
	    "德格县": "627250",
	    "石渠县": "627350",
	    "理塘县": "624300",
	    "乡城县": "627850",
	    "雷波县": "616550",
	    "木里藏族自治县": "615800",
	    "德昌县": "615500",
	    "会东县": "615200",
	    "普格县": "615300",
	    "金阳县": "616250",
	    "喜德县": "616750",
	    "越西县": "616650",
	    "美姑县": "616450",
	    "吉林省": "130000",
	    "长春市": "130000",
	    "南关区": "130000",
	    "朝阳区": "130000",
	    "绿园区": "130000",
	    "农安县": "130200",
	    "榆树市": "130400",
	    "吉林市": "132000",
	    "昌邑区": "132000",
	    "船营区": "132000",
	    "永吉县": "132100",
	    "桦甸市": "132400",
	    "四平市": "136000",
	    "铁西区": "136000",
	    "梨树县": "136500",
	    "公主岭市": "136100",
	    "辽源市": "136200",
	    "龙山区": "136200",
	    "东丰县": "136300",
	    "通化市": "134000",
	    "东昌区": "134000",
	    "通化县": "134100",
	    "柳河县": "135300",
	    "白山市": "134300",
	    "八道江区": "134300",
	    "靖宇县": "135200",
	    "江源县": "134700",
	    "松原市": "138000",
	    "宁江区": "138000",
	    "长岭县": "131500",
	    "白城市": "137000",
	    "洮北区": "137000",
	    "通榆县": "137200",
	    "延边朝鲜族自治州": "133000",
	    "延吉市": "133000",
	    "敦化市": "133700",
	    "龙井市": "133400",
	    "安图县": "133600",
	    "德惠市": "130300",
	    "宽城区": "130000",
	    "二道区": "130000",
	    "双阳区": "130600",
	    "九台市": "130500",
	    "磐石市": "132300",
	    "龙潭区": "132000",
	    "丰满区": "132000",
	    "蛟河市": "132500",
	    "舒兰市": "132600",
	    "双辽市": "136400",
	    "铁东区": "136000",
	    "伊通满族自治县": "130700",
	    "东辽县": "136600",
	    "西安区": "136200",
	    "集安市": "134200",
	    "二道江区": "134000",
	    "辉南县": "135100",
	    "梅河口市": "135000",
	    "临江市": "134600",
	    "抚松县": "134500",
	    "长白朝鲜族自治县": "134400",
	    "扶余县": "131200",
	    "前郭尔罗斯蒙古族自治县": "131100",
	    "乾安县": "131400",
	    "大安市": "131300",
	    "镇赉县": "137300",
	    "洮南市": "137100",
	    "汪清县": "133200",
	    "图们市": "133100",
	    "珲春市": "133300",
	    "和龙市": "133500",
	    "辽宁省": "110000",
	    "沈阳市": "110000",
	    "和平区": "110000",
	    "大东区": "110000",
	    "铁西区": "110020",
	    "东陵区": "110000",
	    "于洪区": "110000",
	    "康平县": "110500",
	    "大连市": "116000",
	    "中山区": "116000",
	    "沙河口区": "116000",
	    "旅顺口区": "116000",
	    "长海县": "116500",
	    "普兰店市": "116200",
	    "鞍山市": "114000",
	    "铁东区": "114000",
	    "立山区": "114000",
	    "台安县": "114100",
	    "抚顺市": "113000",
	    "新抚区": "113000",
	    "望花区": "113000",
	    "抚顺县": "113100",
	    "本溪市": "117000",
	    "平山区": "117000",
	    "明山区": "117000",
	    "本溪满族自治县": "117100",
	    "丹东市": "118000",
	    "元宝区": "118000",
	    "振安区": "118000",
	    "东港市": "118300",
	    "锦州市": "121000",
	    "古塔区": "121000",
	    "太和区": "121000",
	    "义县": "121100",
	    "营口市": "115000",
	    "站前区": "115000",
	    "鲅鱼圈区": "115000",
	    "盖州市": "115200",
	    "阜新市": "123000",
	    "海州区": "123000",
	    "太平区": "123000",
	    "细河区": "123000",
	    "辽阳市": "111000",
	    "白塔区": "111000",
	    "宏伟区": "111000",
	    "太子河区": "111000",
	    "盘锦市": "124000",
	    "双台子区": "124000",
	    "大洼县": "124200",
	    "铁岭市": "112000",
	    "银州区": "112000",
	    "铁岭县": "112600",
	    "昌图县": "112500",
	    "朝阳市": "122000",
	    "双塔区": "122000",
	    "朝阳县": "122000",
	    "喀喇沁左翼蒙古族自治县": "122300",
	    "葫芦岛市": "125000",
	    "连山区": "125000",
	    "南票区": "125000",
	    "建昌县": "125300",
	    "新民市": "110300",
	    "沈河区": "110000",
	    "皇姑区": "110000",
	    "苏家屯区": "110100",
	    "新城子区": "110000",
	    "辽中县": "110200",
	    "法库县": "110400",
	    "庄河市": "116400",
	    "西岗区": "116000",
	    "甘井子区": "116000",
	    "金州区": "116000",
	    "瓦房店市": "116300",
	    "海城市": "114200",
	    "铁西区": "114000",
	    "千山区": "114000",
	    "岫岩满族自治县": "118400",
	    "清原满族自治县": "113300",
	    "东洲区": "113000",
	    "顺城区": "113000",
	    "新宾满族自治县": "113200",
	    "桓仁满族自治县": "117200",
	    "溪湖区": "117000",
	    "南芬区": "117000",
	    "凤城市": "118100",
	    "振兴区": "118000",
	    "宽甸满族自治县": "118200",
	    "北宁市": "121300",
	    "凌河区": "121000",
	    "黑山县": "121400",
	    "凌海市": "121200",
	    "大石桥市": "115100",
	    "西市区": "115000",
	    "老边区": "115000",
	    "彰武县": "123200",
	    "新邱区": "123000",
	    "清河门区": "123000",
	    "阜新蒙古族自治县": "123100",
	    "灯塔市": "111300",
	    "文圣区": "111000",
	    "弓长岭区": "111000",
	    "辽阳县": "111200",
	    "盘山县": "124100",
	    "兴隆台区": "124000",
	    "开原市": "112300",
	    "清河区": "112000",
	    "西丰县": "112400",
	    "凌源市": "122500",
	    "龙城区": "122000",
	    "建平县": "122400",
	    "北票市": "122100",
	    "兴城市": "125100",
	    "龙港区": "125000",
	    "绥中县": "125200",
	    "内蒙古自治区": "010000",
	    "呼和浩特市": "010000",
	    "新城区": "010000",
	    "玉泉区": "010000",
	    "托克托县": "010200",
	    "清水河县": "011600",
	    "包头市": "014000",
	    "东河区": "014000",
	    "青山区": "014000",
	    "土默特右旗": "014100",
	    "乌海市": "016000",
	    "海勃湾区": "016000",
	    "赤峰市": "024000",
	    "红山区": "024000",
	    "松山区": "024000",
	    "巴林左旗": "025450",
	    "林西县": "025250",
	    "翁牛特旗": "024500",
	    "宁城县": "024200",
	    "通辽市": "028000",
	    "科尔沁区": "028000",
	    "科尔沁左翼后旗": "028100",
	    "库伦旗": "028200",
	    "扎鲁特旗": "029100",
	    "鄂尔多斯市": "017000",
	    "东胜区": "017000",
	    "准格尔旗": "017100",
	    "鄂托克旗": "016100",
	    "乌审旗": "017300",
	    "呼伦贝尔市": "021000",
	    "海拉尔区": "021000",
	    "莫力达瓦达斡尔族自治旗": "162850",
	    "鄂温克族自治旗": "021100",
	    "新巴尔虎左旗": "021200",
	    "满洲里市": "021400",
	    "扎兰屯市": "162650",
	    "巴彦淖尔市": "015000",
	    "临河区": "015000",
	    "磴口县": "015200",
	    "乌拉特中旗": "015300",
	    "乌兰察布市": "012000",
	    "集宁区": "012000",
	    "化德县": "013350",
	    "兴和县": "013650",
	    "察哈尔右翼前旗": "012200",
	    "察哈尔右翼后旗": "012400",
	    "兴安盟": "137400",
	    "乌兰浩特市": "137400",
	    "科尔沁右翼前旗": "137400",
	    "扎赉特旗": "137600",
	    "锡林郭勒盟": "026000",
	    "二连浩特市": "012600",
	    "阿巴嘎旗": "011400",
	    "苏尼特右旗": "011200",
	    "西乌珠穆沁旗": "026200",
	    "镶黄旗": "013250",
	    "正蓝旗": "027200",
	    "阿拉善盟": "750306",
	    "阿拉善左旗": "750300",
	    "武川县": "011700",
	    "回民区": "010000",
	    "土默特左旗": "010100",
	    "和林格尔县": "011500",
	    "达尔罕茂明安联合旗": "014500",
	    "昆都伦区": "014000",
	    "白云矿区": "014000",
	    "固阳县": "014200",
	    "乌达区": "016000",
	    "海南区": "016000",
	    "元宝山区": "024000",
	    "阿鲁科尔沁旗": "025500",
	    "巴林右旗": "025150",
	    "克什克腾旗": "025350",
	    "喀喇沁旗": "024400",
	    "敖汉旗": "024300",
	    "霍林郭勒市": "029200",
	    "科尔沁左翼中旗": "029300",
	    "开鲁县": "028400",
	    "奈曼旗": "028300",
	    "伊金霍洛旗": "017200",
	    "达拉特旗": "014300",
	    "鄂托克前旗": "016200",
	    "杭锦旗": "017400",
	    "根河市": "022350",
	    "阿荣旗": "162750",
	    "鄂伦春自治旗": "022450",
	    "陈巴尔虎旗": "021500",
	    "新巴尔虎右旗": "021300",
	    "牙克石市": "022150",
	    "额尔古纳市": "022250",
	    "杭锦后旗": "015400",
	    "五原县": "015100",
	    "乌拉特前旗": "014400",
	    "乌拉特后旗": "015500",
	    "丰镇市": "012100",
	    "卓资县": "012300",
	    "商都县": "013400",
	    "凉城县": "013750",
	    "察哈尔右翼中旗": "013500",
	    "四子王旗": "011800",
	    "突泉县": "137500",
	    "阿尔山市": "137400",
	    "科尔沁右翼中旗": "029400",
	    "多伦县": "027300",
	    "锡林浩特市": "026000",
	    "苏尼特左旗": "011300",
	    "东乌珠穆沁旗": "026300",
	    "太仆寺旗": "027000",
	    "正镶白旗": "013800",
	    "额济纳旗": "735400",
	    "阿拉善右旗": "737300",
	    "山东省": "250000",
	    "济南市": "250000",
	    "历下区": "250000",
	    "槐荫区": "250000",
	    "历城区": "250100",
	    "平阴县": "250400",
	    "商河县": "251600",
	    "青岛市": "266000",
	    "市南区": "266000",
	    "四方区": "266000",
	    "崂山区": "266100",
	    "城阳区": "266000",
	    "即墨市": "266200",
	    "胶南市": "266400",
	    "淄博市": "255000",
	    "淄川区": "255100",
	    "博山区": "255200",
	    "周村区": "255300",
	    "高青县": "256300",
	    "枣庄市": "277000",
	    "市中区": "277000",
	    "峄城区": "277300",
	    "山亭区": "277200",
	    "东营市": "257000",
	    "东营区": "257100",
	    "垦利县": "257500",
	    "烟台市": "264000",
	    "芝罘区": "264000",
	    "牟平区": "264100",
	    "长岛县": "265800",
	    "莱阳市": "265200",
	    "蓬莱市": "265600",
	    "栖霞市": "265300",
	    "潍坊市": "261000",
	    "潍城区": "261000",
	    "坊子区": "261200",
	    "临朐县": "262600",
	    "青州市": "262500",
	    "寿光市": "262700",
	    "高密市": "261500",
	    "济宁市": "272000",
	    "市中区": "272000",
	    "微山县": "277600",
	    "金乡县": "272200",
	    "汶上县": "272500",
	    "梁山县": "272600",
	    "兖州市": "272000",
	    "泰安市": "271000",
	    "泰山区": "271000",
	    "宁阳县": "271400",
	    "新泰市": "271200",
	    "威海市": "264200",
	    "环翠区": "264200",
	    "荣成市": "264300",
	    "日照市": "276800",
	    "东港区": "276800",
	    "五莲县": "262300",
	    "莱芜市": "271100",
	    "莱城区": "271100",
	    "临沂市": "276000",
	    "兰山区": "276000",
	    "河东区": "276000",
	    "郯城县": "276100",
	    "苍山县": "277700",
	    "平邑县": "273300",
	    "蒙阴县": "276200",
	    "德州市": "253000",
	    "德城区": "253000",
	    "宁津县": "253400",
	    "临邑县": "251500",
	    "平原县": "253100",
	    "武城县": "253300",
	    "聊城市": "252000",
	    "东昌府区": "252000",
	    "莘县": "252400",
	    "东阿县": "252200",
	    "高唐县": "252800",
	    "滨州市": "256600",
	    "滨城区": "256600",
	    "阳信县": "251800",
	    "沾化县": "256800",
	    "荷泽市": "274000",
	    "牡丹区": "274000",
	    "单县": "274300",
	    "巨野县": "274900",
	    "鄄城县": "274600",
	    "章丘市": "250200",
	    "市中区": "250000",
	    "天桥区": "250000",
	    "长清区": "250300",
	    "济阳县": "251400",
	    "莱西市": "266600",
	    "市北区": "266000",
	    "黄岛区": "266000",
	    "李沧区": "266000",
	    "胶州市": "266300",
	    "平度市": "266700",
	    "沂源县": "256100",
	    "张店区": "255000",
	    "临淄区": "255400",
	    "桓台县": "256400",
	    "滕州市": "277500",
	    "薛城区": "277000",
	    "台儿庄区": "277400",
	    "广饶县": "257300",
	    "河口区": "257200",
	    "利津县": "257400",
	    "海阳市": "265100",
	    "福山区": "265500",
	    "莱山区": "264000",
	    "龙口市": "265700",
	    "莱州市": "261400",
	    "招远市": "265400",
	    "昌邑市": "261300",
	    "寒亭区": "261100",
	    "奎文区": "261000",
	    "昌乐县": "262400",
	    "诸城市": "262200",
	    "安丘市": "262100",
	    "邹城市": "273500",
	    "任城区": "272000",
	    "鱼台县": "272300",
	    "嘉祥县": "272400",
	    "泗水县": "273200",
	    "曲阜市": "273100",
	    "肥城市": "271600",
	    "岱岳区": "271000",
	    "东平县": "271500",
	    "乳山市": "264500",
	    "文登市": "264400",
	    "莒县": "276500",
	    "岚山区": "276800",
	    "钢城区": "271100",
	    "临沭县": "276700",
	    "罗庄区": "276000",
	    "沂南县": "276300",
	    "沂水县": "276400",
	    "费县": "273400",
	    "莒南县": "276600",
	    "禹城市": "251200",
	    "陵县": "253500",
	    "庆云县": "253700",
	    "齐河县": "251100",
	    "夏津县": "253200",
	    "乐陵市": "253600",
	    "临清市": "252600",
	    "阳谷县": "252300",
	    "茌平县": "252100",
	    "冠县": "252500",
	    "邹平县": "256200",
	    "惠民县": "251700",
	    "无棣县": "251900",
	    "博兴县": "256500",
	    "东明县": "274500",
	    "曹县": "274400",
	    "成武县": "274200",
	    "郓城县": "274700",
	    "定陶县": "274100",
	    "上海市": "200000",
	    "黄浦区": "200001",
	    "徐汇区": "200030",
	    "静安区": "200040",
	    "闸北区": "200070",
	    "杨浦区": "200070",
	    "宝山区": "201900",
	    "浦东新区": "200120",
	    "松江区": "201600",
	    "南汇区": "201300",
	    "崇明县": "202150",
	    "卢湾区": "200020",
	    "长宁区": "200050",
	    "普陀区": "200333",
	    "虹口区": "200080",
	    "闵行区": "201100",
	    "嘉定区": "201800",
	    "金山区": "201500",
	    "青浦区": "201700",
	    "奉贤区": "201400",
	    "山西省": "030000",
	    "太原市": "030000",
	    "小店区": "030000",
	    "杏花岭区": "030000",
	    "万柏林区": "030000",
	    "清徐县": "030400",
	    "娄烦县": "030300",
	    "大同市": "037000",
	    "城区": "037000",
	    "南郊区": "037000",
	    "阳高县": "038100",
	    "广灵县": "037500",
	    "浑源县": "037400",
	    "阳泉市": "045000",
	    "城区": "045000",
	    "郊区": "045000",
	    "长治市": "046000",
	    "城区": "046000",
	    "长治县": "047100",
	    "屯留县": "046100",
	    "黎城县": "047600",
	    "长子县": "046600",
	    "沁县": "046400",
	    "晋城市": "048000",
	    "城区": "048000",
	    "阳城县": "048100",
	    "泽州县": "048000",
	    "朔州市": "038500",
	    "朔城区": "038500",
	    "山阴县": "038400",
	    "右玉县": "037200",
	    "晋中市": "038300",
	    "榆次区": "030600",
	    "左权县": "032600",
	    "昔阳县": "045300",
	    "太谷县": "030800",
	    "平遥县": "031100",
	    "运城市": "044000",
	    "盐湖区": "044000",
	    "万荣县": "044200",
	    "稷山县": "043200",
	    "绛县": "043600",
	    "夏县": "044400",
	    "芮城县": "044600",
	    "忻州市": "034000",
	    "忻府区": "034000",
	    "五台县": "035500",
	    "繁峙县": "034300",
	    "静乐县": "035100",
	    "五寨县": "036200",
	    "河曲县": "036500",
	    "偏关县": "036400",
	    "临汾市": "041000",
	    "尧都区": "041000",
	    "翼城县": "043500",
	    "洪洞县": "031600",
	    "安泽县": "042500",
	    "吉县": "042200",
	    "大宁县": "042300",
	    "永和县": "041400",
	    "汾西县": "031500",
	    "吕梁市": "033000",
	    "离石区": "033000",
	    "交城县": "030500",
	    "临县": "033200",
	    "石楼县": "032500",
	    "方山县": "033100",
	    "交口县": "032400",
	    "古交市": "030200",
	    "迎泽区": "030000",
	    "尖草坪区": "030000",
	    "晋源区": "030000",
	    "阳曲县": "030100",
	    "大同县": "037300",
	    "矿区": "037000",
	    "新荣区": "037000",
	    "天镇县": "038200",
	    "灵丘县": "034400",
	    "左云县": "037100",
	    "盂县": "045100",
	    "矿区": "045000",
	    "平定县": "045200",
	    "潞城市": "047500",
	    "郊区": "046000",
	    "襄垣县": "046200",
	    "平顺县": "047400",
	    "壶关县": "047300",
	    "武乡县": "046300",
	    "沁源县": "046500",
	    "高平市": "046700",
	    "沁水县": "048200",
	    "陵川县": "048300",
	    "怀仁县": "038300",
	    "平鲁区": "038500",
	    "应县": "037600",
	    "介休市": "031200",
	    "榆社县": "031800",
	    "和顺县": "032700",
	    "寿阳县": "031700",
	    "祁县": "030900",
	    "灵石县": "031300",
	    "河津市": "043300",
	    "临猗县": "044100",
	    "闻喜县": "043800",
	    "新绛县": "043100",
	    "垣曲县": "043700",
	    "平陆县": "044300",
	    "永济市": "044500",
	    "原平市": "034100",
	    "定襄县": "035400",
	    "代县": "034200",
	    "宁武县": "036000",
	    "神池县": "036100",
	    "岢岚县": "036300",
	    "保德县": "036600",
	    "霍州市": "031400",
	    "曲沃县": "043400",
	    "襄汾县": "041500",
	    "古县": "042400",
	    "浮山县": "042600",
	    "乡宁县": "042100",
	    "隰县": "041300",
	    "蒲县": "041200",
	    "侯马市": "043000",
	    "汾阳市": "032200",
	    "文水县": "032100",
	    "兴县": "035300",
	    "柳林县": "033300",
	    "岚县": "035200",
	    "中阳县": "033400",
	    "孝义市": "032300",
	    "天津市": "300000",
	    "和平区": "300000",
	    "河西区": "300000",
	    "河北区": "300000",
	    "塘沽区": "300450",
	    "大港区": "300000",
	    "西青区": "300000",
	    "北辰区": "300000",
	    "宝坻区": "301800",
	    "静海县": "301600",
	    "河东区": "300000",
	    "南开区": "300000",
	    "红桥区": "300000",
	    "汉沽区": "300480",
	    "东丽区": "300000",
	    "津南区": "300000",
	    "武清区": "301700",
	    "宁河县": "301500",
	    "蓟县": "301900",
	    "西藏自治区": "850000",
	    "拉萨市": "850000",
	    "城关区": "850000",
	    "当雄县": "851500",
	    "曲水县": "850600",
	    "墨竹工卡县": "850200",
	    "昌都地区": "854000",
	    "昌都县": "854000",
	    "贡觉县": "854200",
	    "丁青县": "855700",
	    "八宿县": "854600",
	    "芒康县": "854500",
	    "山南地区": "856000",
	    "乃东县": "856100",
	    "贡嘎县": "850700",
	    "琼结县": "856800",
	    "措美县": "856900",
	    "加查县": "856400",
	    "错那县": "856700",
	    "日喀则地区": "857000",
	    "日喀则市": "857000",
	    "江孜县": "857400",
	    "萨迦县": "857800",
	    "昂仁县": "858500",
	    "白朗县": "857300",
	    "康马县": "857500",
	    "仲巴县": "858800",
	    "吉隆县": "858700",
	    "萨嘎县": "858600",
	    "那曲地区": "852000",
	    "那曲县": "852000",
	    "比如县": "852300",
	    "安多县": "853400",
	    "索县": "852200",
	    "巴青县": "852100",
	    "阿里地区": "859000",
	    "普兰县": "859500",
	    "噶尔县": "859000",
	    "革吉县": "859100",
	    "林芝地区": "860000",
	    "林芝县": "860100",
	    "米林县": "860500",
	    "波密县": "860300",
	    "达孜县": "850100",
	    "林周县": "851600",
	    "尼木县": "851600",
	    "堆龙德庆县": "851400",
	    "边坝县": "855500",
	    "江达县": "854100",
	    "类乌齐县": "855600",
	    "察雅县": "854300",
	    "左贡县": "854400",
	    "洛隆县": "855400",
	    "浪卡子县": "851100",
	    "扎囊县": "850800",
	    "桑日县": "856200",
	    "曲松县": "856300",
	    "洛扎县": "851200",
	    "隆子县": "856600",
	    "岗巴县": "857700",
	    "南木林县": "857100",
	    "定日县": "858200",
	    "拉孜县": "858100",
	    "谢通门县": "858900",
	    "仁布县": "857200",
	    "定结县": "857900",
	    "亚东县": "857600",
	    "聂拉木县": "858300",
	    "尼玛县": "853200",
	    "嘉黎县": "852400",
	    "聂荣县": "853500",
	    "申扎县": "853100",
	    "班戈县": "852500",
	    "措勤县": "859300",
	    "札达县": "859600",
	    "日土县": "859700",
	    "改则县": "859200",
	    "朗县": "860400",
	    "工布江达县": "860200",
	    "墨脱县": "860700",
	    "察隅县": "860600",
	    "海南省": "570000",
	    "海口市": "570100",
	    "秀英区": "570100",
	    "琼山区": "571100",
	    "三亚市": "572000",
	    "五指山市": "572200",
	    "儋州市": "571700",
	    "万宁市": "571500",
	    "定安县": "571200",
	    "澄迈县": "571900",
	    "白沙黎族自治县": "572800",
	    "乐东黎族自治县": "572500",
	    "保亭黎族苗族自治县": "572300",
	    "西沙群岛": "572000",
	    "美兰区": "570100",
	    "龙华区": "570100",
	    "中沙群岛的岛礁及其海域": "572000",
	    "琼海市": "571400",
	    "文昌市": "571300",
	    "东方市": "572600",
	    "屯昌县": "571600",
	    "临高县": "571800",
	    "昌江黎族自治县": "572700",
	    "陵水黎族自治县": "572400",
	    "琼中黎族苗族自治县": "572900",
	    "南沙群岛": "572000",
	    "陕西省": "710000",
	    "西安市": "710000",
	    "新城区": "710000",
	    "莲湖区": "710000",
	    "未央区": "710000",
	    "阎良区": "710000",
	    "长安区": "710100",
	    "周至县": "710400",
	    "铜川市": "727000",
	    "耀州区": "727100",
	    "宝鸡市": "721000",
	    "渭滨区": "721000",
	    "陈仓区": "721300",
	    "岐山县": "722400",
	    "眉县": "722300",
	    "千阳县": "721100",
	    "凤县": "721700",
	    "咸阳市": "712000",
	    "秦都区": "712000",
	    "渭城区": "712000",
	    "泾阳县": "713700",
	    "礼泉县": "713200",
	    "彬县": "713500",
	    "旬邑县": "711300",
	    "武功县": "712200",
	    "渭南市": "714000",
	    "临渭区": "714000",
	    "潼关县": "714300",
	    "合阳县": "715300",
	    "蒲城县": "715500",
	    "富平县": "711700",
	    "延安市": "716000",
	    "宝塔区": "716000",
	    "延川县": "717200",
	    "安塞县": "717400",
	    "吴旗县": "717600",
	    "富县": "727500",
	    "宜川县": "716200",
	    "汉中市": "723000",
	    "汉台区": "723000",
	    "城固县": "723200",
	    "西乡县": "723500",
	    "宁强县": "724400",
	    "镇巴县": "723600",
	    "榆林市": "719000",
	    "榆阳区": "719000",
	    "横山县": "719200",
	    "定边县": "718600",
	    "米脂县": "718100",
	    "吴堡县": "718200",
	    "安康市": "725000",
	    "汉滨区": "725000",
	    "石泉县": "725200",
	    "紫阳县": "725300",
	    "平利县": "725500",
	    "旬阳县": "725700",
	    "商洛市": "726000",
	    "商州区": "726000",
	    "丹凤县": "726200",
	    "山阳县": "726400",
	    "柞水县": "711400",
	    "高陵县": "710200",
	    "碑林区": "710000",
	    "灞桥区": "710000",
	    "雁塔区": "710000",
	    "临潼区": "710600",
	    "蓝田县": "710500",
	    "户县": "710300",
	    "宜君县": "727200",
	    "太白县": "721600",
	    "金台区": "721000",
	    "凤翔县": "721400",
	    "扶风县": "722200",
	    "陇县": "721200",
	    "麟游县": "721500",
	    "兴平市": "713100",
	    "杨陵区": "712100",
	    "三原县": "713800",
	    "乾县": "713300",
	    "永寿县": "713400",
	    "长武县": "713600",
	    "淳化县": "711200",
	    "华阴市": "714200",
	    "华县": "714100",
	    "大荔县": "715100",
	    "澄城县": "715200",
	    "白水县": "715600",
	    "韩城市": "715400",
	    "黄陵县": "727300",
	    "延长县": "717100",
	    "子长县": "717300",
	    "志丹县": "717500",
	    "甘泉县": "716100",
	    "洛川县": "727400",
	    "黄龙县": "715700",
	    "佛坪县": "723400",
	    "南郑县": "723100",
	    "洋县": "723300",
	    "勉县": "724200",
	    "略阳县": "724300",
	    "留坝县": "724100",
	    "子洲县": "718400",
	    "府谷县": "719400",
	    "靖边县": "718500",
	    "绥德县": "718000",
	    "佳县": "719200",
	    "清涧县": "718300",
	    "白河县": "725800",
	    "汉阴县": "725100",
	    "宁陕县": "711600",
	    "岚皋县": "725400",
	    "镇坪县": "725600",
	    "神木县": "719300",
	    "洛南县": "726100",
	    "商南县": "726300",
	    "镇安县": "711500",
	    "甘肃省": "730000",
	    "兰州市": "730000",
	    "城关区": "730030",
	    "西固区": "730060",
	    "红古区": "730080",
	    "皋兰县": "730200",
	    "嘉峪关市": "735100",
	    "金川区": "737100",
	    "白银市": "730900",
	    "白银区": "730900",
	    "靖远县": "730600",
	    "天水市": "741000",
	    "秦州区": "741000",
	    "清水县": "741400",
	    "甘谷县": "741200",
	    "武威市": "733000",
	    "凉州区": "733000",
	    "古浪县": "733100",
	    "张掖市": "734000",
	    "甘州区": "734000",
	    "民乐县": "734500",
	    "高台县": "734300",
	    "平凉市": "744000",
	    "崆峒区": "744000",
	    "灵台县": "744400",
	    "华亭县": "744100",
	    "酒泉市": "735000",
	    "肃州区": "735000",
	    "安西县": "736100",
	    "阿克塞哈萨克族自治县": "736400",
	    "庆阳市": "745000",
	    "西峰区": "745000",
	    "环县": "745700",
	    "合水县": "745400",
	    "宁县": "745200",
	    "定西市": "743000",
	    "安定区": "744300",
	    "陇西县": "748100",
	    "临洮县": "730500",
	    "陇南市": "742500",
	    "武都区": "746000",
	    "文县": "746400",
	    "康县": "746500",
	    "礼县": "742200",
	    "临夏回族自治州": "731100",
	    "临夏市": "731100",
	    "康乐县": "731500",
	    "广河县": "731300",
	    "东乡族自治县": "731400",
	    "甘南藏族自治州": "747000",
	    "合作市": "747000",
	    "卓尼县": "747600",
	    "迭部县": "747400",
	    "夏河县": "747100",
	    "榆中县": "730100",
	    "七里河区": "730050",
	    "安宁区": "730070",
	    "永登县": "730300",
	    "金昌市": "737100",
	    "永昌县": "737200",
	    "景泰县": "730400",
	    "平川区": "730900",
	    "会宁县": "730700",
	    "麦积区": "741020",
	    "秦安县": "741600",
	    "武山县": "741300",
	    "天祝藏族自治县": "733200",
	    "民勤县": "733300",
	    "山丹县": "734100",
	    "肃南裕固族自治县": "734400",
	    "临泽县": "734200",
	    "静宁县": "743400",
	    "泾川县": "744300",
	    "崇信县": "744200",
	    "庄浪县": "744600",
	    "敦煌市": "736200",
	    "金塔县": "735300",
	    "肃北蒙古族自治县": "736300",
	    "玉门市": "735200",
	    "镇原县": "744500",
	    "庆阳县": "745100",
	    "华池县": "745600",
	    "正宁县": "745300",
	    "岷县": "748400",
	    "通渭县": "743300",
	    "渭源县": "748200",
	    "漳县": "748300",
	    "两当县": "742400",
	    "成县": "742500",
	    "宕昌县": "748500",
	    "西和县": "742100",
	    "徽县": "742300",
	    "积石山保安族东乡族撒拉族自治县": "731700",
	    "临夏县": "731800",
	    "永靖县": "731600",
	    "和政县": "731200",
	    "碌曲县": "747200",
	    "临潭县": "747500",
	    "舟曲县": "746300",
	    "玛曲县": "747300",
	    "宁夏回族自治区": "750000",
	    "银川市": "750000",
	    "兴庆区": "750000",
	    "金凤区": "750000",
	    "贺兰县": "750200",
	    "石嘴山市": "753000",
	    "大武口区": "753000",
	    "吴忠市": "751100",
	    "利通区": "751100",
	    "同心县": "751300",
	    "固原市": "756000",
	    "原州区": "756000",
	    "隆德县": "756300",
	    "中卫市": "751700",
	    "沙坡头区": "751700",
	    "灵武市": "751400",
	    "西夏区": "750000",
	    "永宁县": "750100",
	    "平罗县": "753400",
	    "惠农区": "753600",
	    "青铜峡市": "751600",
	    "盐池县": "751500",
	    "彭阳县": "756500",
	    "西吉县": "756200",
	    "泾源县": "756400",
	    "海原县": "751800",
	    "中宁县": "751200",
	    "青海省": "810000",
	    "西宁市": "810000",
	    "城东区": "810000",
	    "城西区": "810000",
	    "大通回族土族自治县": "810100",
	    "海东地区": "810600",
	    "平安县": "810600",
	    "乐都县": "810700",
	    "化隆回族自治县": "810900",
	    "海北藏族自治州": "812200",
	    "门源回族自治县": "810300",
	    "海晏县": "812200",
	    "黄南藏族自治州": "811300",
	    "同仁县": "811300",
	    "泽库县": "811400",
	    "海南藏族自治州": "813000",
	    "共和县": "813000",
	    "贵德县": "811700",
	    "果洛藏族自治州": "814000",
	    "玛沁县": "814000",
	    "甘德县": "814100",
	    "久治县": "624700",
	    "玉树藏族自治州": "815000",
	    "玉树县": "815000",
	    "称多县": "815100",
	    "囊谦县": "815200",
	    "海西蒙古族藏族自治州": "817000",
	    "格尔木市": "816000",
	    "乌兰县": "817100",
	    "湟源县": "812100",
	    "城中区": "810000",
	    "城北区": "810000",
	    "湟中县": "811600",
	    "循化撒拉族自治县": "811100",
	    "民和回族土族自治县": "810800",
	    "互助土族自治县": "810500",
	    "刚察县": "812300",
	    "祁连县": "810400",
	    "河南蒙古族自治县": "811500",
	    "尖扎县": "811200",
	    "贵南县": "813100",
	    "同德县": "813200",
	    "兴海县": "813300",
	    "班玛县": "814300",
	    "达日县": "814200",
	    "玛多县": "813500",
	    "曲麻莱县": "815500",
	    "杂多县": "815300",
	    "治多县": "815400",
	    "天峻县": "817200",
	    "德令哈市": "817000",
	    "都兰县": "816100",
	    "新疆维吾尔自治区": "830000",
	    "乌鲁木齐市": "830000",
	    "天山区": "830000",
	    "新市区": "830000",
	    "头屯河区": "830000",
	    "克拉玛依市": "834000",
	    "独山子区": "838600",
	    "白碱滩区": "834000",
	    "吐鲁番地区": "838000",
	    "吐鲁番市": "838000",
	    "哈密地区": "839000",
	    "哈密市": "839000",
	    "昌吉回族自治州": "831100",
	    "昌吉市": "831100",
	    "米泉市": "831400",
	    "玛纳斯县": "832200",
	    "吉木萨尔县": "831700",
	    "博尔塔拉蒙古自治州": "833400",
	    "博乐市": "833400",
	    "巴音郭楞蒙古自治州": "841000",
	    "库尔勒市": "841000",
	    "尉犁县": "841500",
	    "且末县": "841900",
	    "和静县": "841300",
	    "阿克苏地区": "843000",
	    "阿克苏市": "843000",
	    "库车县": "842000",
	    "新和县": "842100",
	    "乌什县": "843400",
	    "克孜勒苏柯尔克孜自治州": "845350",
	    "阿图什市": "845350",
	    "阿合奇县": "843500",
	    "喀什地区": "844000",
	    "喀什市": "844000",
	    "疏勒县": "844200",
	    "泽普县": "844800",
	    "叶城县": "844900",
	    "岳普湖县": "844400",
	    "塔什库尔干塔吉克自治县": "845250",
	    "和田地区": "848000",
	    "和田市": "848000",
	    "墨玉县": "848100",
	    "洛浦县": "848200",
	    "于田县": "848400",
	    "伊犁哈萨克自治州": "835000",
	    "伊宁市": "835000",
	    "伊宁县": "835100",
	    "霍城县": "835200",
	    "新源县": "835800",
	    "尼勒克县": "835700",
	    "塔城地区": "834700",
	    "塔城市": "834300",
	    "额敏县": "834600",
	    "托里县": "834500",
	    "阿勒泰地区": "836500",
	    "阿勒泰市": "836500",
	    "富蕴县": "836100",
	    "哈巴河县": "836700",
	    "石河子市": "832000",
	    "图木舒克市": "844000",
	    "东山区": "830000",
	    "沙依巴克区": "830000",
	    "水磨沟区": "830000",
	    "乌尔禾区": "834000",
	    "克拉玛依区": "834000",
	    "托克逊县": "838100",
	    "鄯善县": "838200",
	    "伊吾县": "839300",
	    "巴里坤哈萨克自治县": "839200",
	    "木垒哈萨克自治县": "831900",
	    "阜康市": "831500",
	    "呼图壁县": "831200",
	    "奇台县": "831800",
	    "温泉县": "833500",
	    "精河县": "833300",
	    "博湖县": "841400",
	    "轮台县": "841600",
	    "若羌县": "841800",
	    "焉耆回族自治县": "841100",
	    "和硕县": "841200",
	    "温宿县": "843100",
	    "沙雅县": "842200",
	    "拜城县": "842300",
	    "阿瓦提县": "843200",
	    "乌恰县": "845450",
	    "阿克陶县": "845550",
	    "巴楚县": "843800",
	    "疏附县": "844100",
	    "英吉沙县": "844500",
	    "莎车县": "844700",
	    "麦盖提县": "844600",
	    "伽师县": "844300",
	    "民丰县": "848500",
	    "和田县": "848000",
	    "皮山县": "845150",
	    "策勒县": "848300",
	    "特克斯县": "835500",
	    "奎屯市": "833200",
	    "察布查尔锡伯自治县": "835300",
	    "巩留县": "835400",
	    "昭苏县": "835600",
	    "和布克赛尔蒙古自治县": "834400",
	    "乌苏市": "833300",
	    "沙湾县": "832100",
	    "裕民县": "834800",
	    "吉木乃县": "836800",
	    "布尔津县": "836600",
	    "福海县": "836400",
	    "青河县": "836200",
	    "阿拉尔市": "843300",
	    "五家渠市": "831300",
	    "浙江省": "310000",
	    "杭州市": "310000",
	    "上城区": "310000",
	    "江干区": "310000",
	    "西湖区": "310000",
	    "萧山区": "311200",
	    "桐庐县": "311500",
	    "建德市": "311600",
	    "宁波市": "315000",
	    "海曙区": "315000",
	    "江北区": "315000",
	    "镇海区": "315200",
	    "象山县": "315700",
	    "余姚市": "315400",
	    "温州市": "325000",
	    "鹿城区": "325000",
	    "瓯海区": "325000",
	    "永嘉县": "325100",
	    "苍南县": "325800",
	    "泰顺县": "325500",
	    "嘉兴市": "314000",
	    "秀城区": "314000",
	    "海盐县": "314300",
	    "桐乡市": "314500",
	    "湖州市": "313000",
	    "吴兴区": "313000",
	    "德清县": "313200",
	    "绍兴市": "312000",
	    "越城区": "312000",
	    "新昌县": "312500",
	    "上虞市": "312300",
	    "金华市": "321000",
	    "婺城区": "321000",
	    "武义县": "321200",
	    "磐安县": "322300",
	    "义乌市": "322000",
	    "衢州市": "324000",
	    "柯城区": "324000",
	    "常山县": "324200",
	    "龙游县": "324400",
	    "舟山市": "316000",
	    "定海区": "316000",
	    "岱山县": "316200",
	    "台州市": "318000",
	    "椒江区": "317700",
	    "路桥区": "318000",
	    "三门县": "317100",
	    "仙居县": "317300",
	    "丽水市": "323000",
	    "莲都区": "323000",
	    "缙云县": "321400",
	    "松阳县": "323400",
	    "庆元县": "323800",
	    "临安市": "311300",
	    "下城区": "310000",
	    "拱墅区": "310000",
	    "滨江区": "310000",
	    "余杭区": "311100",
	    "淳安县": "311700",
	    "富阳市": "311400",
	    "奉化市": "315500",
	    "江东区": "315000",
	    "北仑区": "315800",
	    "鄞州区": "315100",
	    "宁海县": "315600",
	    "慈溪市": "315300",
	    "乐清市": "325600",
	    "龙湾区": "325000",
	    "洞头县": "325700",
	    "平阳县": "325400",
	    "文成县": "325300",
	    "瑞安市": "325200",
	    "平湖市": "314200",
	    "嘉善县": "314100",
	    "海宁市": "314400",
	    "安吉县": "313300",
	    "南浔区": "313000",
	    "长兴县": "313100",
	    "嵊州市": "312400",
	    "绍兴县": "312000",
	    "诸暨市": "311800",
	    "永康市": "321300",
	    "金东区": "321000",
	    "浦江县": "322200",
	    "兰溪市": "321100",
	    "东阳市": "322100",
	    "江山市": "324100",
	    "衢江区": "324000",
	    "开化县": "324300",
	    "嵊泗县": "202450",
	    "普陀区": "316100",
	    "临海市": "317000",
	    "黄岩区": "318020",
	    "玉环县": "317600",
	    "天台县": "317200",
	    "温岭市": "317500",
	    "龙泉市": "323700",
	    "青田县": "323900",
	    "遂昌县": "323300",
	    "云和县": "323600",
	    "景宁畲族自治县": "323500",
	    "福建省": "350000",
	    "福州市": "350000",
	    "鼓楼区": "350000",
	    "仓山区": "350000",
	    "晋安区": "350000",
	    "连江县": "350500",
	    "闽清县": "350800",
	    "平潭县": "350400",
	    "厦门市": "361000",
	    "思明区": "361000",
	    "湖里区": "361000",
	    "同安区": "361100",
	    "莆田市": "351100",
	    "城厢区": "351100",
	    "荔城区": "351100",
	    "三明市": "365000",
	    "梅列区": "365000",
	    "明溪县": "365300",
	    "宁化县": "365400",
	    "尤溪县": "365100",
	    "将乐县": "353300",
	    "建宁县": "354500",
	    "泉州市": "362000",
	    "鲤城区": "362000",
	    "洛江区": "362000",
	    "惠安县": "362100",
	    "永春县": "362600",
	    "金门县": "362000",
	    "晋江市": "362200",
	    "漳州市": "363000",
	    "芗城区": "363000",
	    "云霄县": "363300",
	    "诏安县": "363500",
	    "东山县": "363400",
	    "平和县": "363700",
	    "南平市": "353000",
	    "延平区": "353000",
	    "浦城县": "353400",
	    "松溪县": "353500",
	    "邵武市": "354000",
	    "建瓯市": "353100",
	    "龙岩市": "364000",
	    "新罗区": "364000",
	    "永定县": "364100",
	    "武平县": "364300",
	    "宁德市": "352000",
	    "蕉城区": "352000",
	    "古田县": "352200",
	    "寿宁县": "355500",
	    "柘荣县": "355300",
	    "长乐市": "350200",
	    "台江区": "350000",
	    "马尾区": "350000",
	    "闽侯县": "350100",
	    "罗源县": "350600",
	    "永泰县": "350700",
	    "福清市": "350300",
	    "翔安区": "361100",
	    "海沧区": "361000",
	    "集美区": "361000",
	    "仙游县": "351200",
	    "涵江区": "351100",
	    "秀屿区": "351100",
	    "永安市": "366000",
	    "三元区": "365000",
	    "清流县": "365300",
	    "大田县": "366100",
	    "沙县": "365500",
	    "泰宁县": "354400",
	    "南安市": "362300",
	    "丰泽区": "362000",
	    "泉港区": "362100",
	    "安溪县": "362400",
	    "德化县": "362500",
	    "石狮市": "362700",
	    "龙海市": "363100",
	    "龙文区": "363000",
	    "漳浦县": "363200",
	    "长泰县": "363900",
	    "南靖县": "363600",
	    "华安县": "363800",
	    "建阳市": "354200",
	    "顺昌县": "353200",
	    "光泽县": "354100",
	    "政和县": "353600",
	    "武夷山市": "354300",
	    "漳平市": "364400",
	    "长汀县": "366300",
	    "上杭县": "364200",
	    "连城县": "366200",
	    "福鼎市": "355200",
	    "霞浦县": "355100",
	    "屏南县": "352300",
	    "周宁县": "355400",
	    "福安市": "355000",
	    "黑龙江省": "150000",
	    "哈尔滨市": "150000",
	    "道里区": "150000",
	    "道外区": "150000",
	    "动力区": "150000",
	    "松北区": "150000",
	    "依兰县": "154800",
	    "宾县": "150400",
	    "木兰县": "151900",
	    "延寿县": "150700",
	    "双城市": "150100",
	    "齐齐哈尔市": "161000",
	    "龙沙区": "161000",
	    "铁锋区": "161000",
	    "富拉尔基区": "161000",
	    "梅里斯达斡尔族区": "161000",
	    "依安县": "161500",
	    "甘南县": "162100",
	    "克山县": "161600",
	    "拜泉县": "164700",
	    "鸡西市": "158100",
	    "鸡冠区": "158100",
	    "滴道区": "158100",
	    "城子河区": "158100",
	    "鸡东县": "158200",
	    "鹤岗市": "154100",
	    "向阳区": "154100",
	    "南山区": "154100",
	    "东山区": "154100",
	    "萝北县": "154200",
	    "双鸭山市": "155100",
	    "尖山区": "155100",
	    "四方台区": "155100",
	    "集贤县": "155900",
	    "宝清县": "155600",
	    "大庆市": "163000",
	    "萨尔图区": "163000",
	    "让胡路区": "163000",
	    "大同区": "163000",
	    "肇源县": "166500",
	    "伊春市": "153000",
	    "伊春区": "153000",
	    "友好区": "153000",
	    "翠峦区": "153000",
	    "美溪区": "153000",
	    "五营区": "153000",
	    "汤旺河区": "153000",
	    "乌伊岭区": "153000",
	    "上甘岭区": "153000",
	    "佳木斯市": "154000",
	    "永红区": "154000",
	    "前进区": "154000",
	    "郊区": "154000",
	    "桦川县": "154300",
	    "抚远县": "156500",
	    "七台河市": "154600",
	    "新兴区": "154600",
	    "茄子河区": "154600",
	    "牡丹江市": "157000",
	    "东安区": "157000",
	    "爱民区": "157000",
	    "东宁县": "157200",
	    "绥芬河市": "157300",
	    "宁安市": "157400",
	    "黑河市": "164300",
	    "爱辉区": "164300",
	    "逊克县": "164400",
	    "北安市": "164000",
	    "绥化市": "152000",
	    "北林区": "152000",
	    "兰西县": "151500",
	    "庆安县": "152400",
	    "绥棱县": "152200",
	    "肇东市": "151100",
	    "大兴安岭地区": "165000",
	    "呼玛县": "165100",
	    "五常市": "150200",
	    "南岗区": "150000",
	    "香坊区": "150000",
	    "平房区": "150000",
	    "呼兰区": "150500",
	    "方正县": "150800",
	    "巴彦县": "151800",
	    "通河县": "150900",
	    "阿城市": "150300",
	    "尚志市": "150600",
	    "建华区": "161000",
	    "昂昂溪区": "161000",
	    "碾子山区": "161000",
	    "龙江县": "161100",
	    "泰来县": "162400",
	    "富裕县": "161200",
	    "克东县": "164800",
	    "讷河市": "161300",
	    "密山市": "158300",
	    "恒山区": "158100",
	    "梨树区": "158100",
	    "麻山区": "158100",
	    "虎林市": "158400",
	    "工农区": "154100",
	    "兴安区": "154100",
	    "兴山区": "154100",
	    "绥滨县": "156200",
	    "岭东区": "155100",
	    "宝山区": "155100",
	    "友谊县": "155800",
	    "饶河县": "155700",
	    "杜尔伯特蒙古族自治县": "166200",
	    "龙凤区": "163000",
	    "红岗区": "163000",
	    "肇州县": "166400",
	    "林甸县": "166300",
	    "铁力市": "152500",
	    "南岔区": "153000",
	    "西林区": "153000",
	    "新青区": "153000",
	    "金山屯区": "153000",
	    "乌马河区": "153000",
	    "带岭区": "153000",
	    "红星区": "153000",
	    "嘉荫县": "153200",
	    "富锦市": "156100",
	    "向阳区": "154000",
	    "东风区": "154000",
	    "桦南县": "154400",
	    "汤原县": "154700",
	    "同江市": "156400",
	    "桃山区": "154600",
	    "勃利县": "154500",
	    "阳明区": "157000",
	    "西安区": "157000",
	    "林口县": "157600",
	    "海林市": "157100",
	    "穆棱市": "157500",
	    "嫩江县": "161400",
	    "孙吴县": "164200",
	    "五大连池市": "164100",
	    "望奎县": "152100",
	    "青冈县": "151600",
	    "明水县": "151700",
	    "安达市": "151400",
	    "海伦市": "152300",
	    "漠河县": "165300",
	    "塔河县": "165200"
	};
	
	return {
		"findPostCode":findPostCode
	};
});